/*------------------------------------------------------------------------------
	インクルード
------------------------------------------------------------------------------*/
#include <stdio.h>
#include <math.h>
#include <stdarg.h>

/*------------------------------------------------------------------------------
	デファイン
------------------------------------------------------------------------------*/
#define CNT   492
#define OUT   9
#define DAYS  21
#define MAX   625
#define MIN   475
#define RANGE 150
#define STEP1 5
#define STEP2 25

/*------------------------------------------------------------------------------
	マクロ
------------------------------------------------------------------------------*/
#define PRINT(x, ...)  fprintf_crlf((char *)x, ##__VA_ARGS__)

/*------------------------------------------------------------------------------
	型定義
------------------------------------------------------------------------------*/
typedef char INT8;
typedef int  INT32;

/*------------------------------------------------------------------------------
	構造体
------------------------------------------------------------------------------*/
typedef struct Field {
	INT32  date;
	double sta;
	double max;
	double min;
	double end;
	double ratio;
	INT32  trade;
} Field;

/*------------------------------------------------------------------------------
	ローカル変数
------------------------------------------------------------------------------*/
FILE *fp;
double ave5 [CNT];
double ave25[CNT];
double ave75[CNT];
double ave100[CNT];
Field tmp[CNT];

/*------------------------------------------------------------------------------
	内部参照
------------------------------------------------------------------------------*/
extern Field field[CNT];

/*------------------------------------------------------------------------------
	プロトタイプ
------------------------------------------------------------------------------*/
void difinition(void);
void sort(void);
void clear(void);
void graph(void);
void header(void);
void footer(void);
void hit(void);
void fixed(void);
void fprintf_crlf(char *pStr, ...);

/*------------------------------------------------------------------------------
	書式：int main(void)
	引数：-
	戻値：int  -
	機能：スタートアップ
------------------------------------------------------------------------------*/
int main(void)
{
	fp = fopen("full.txt", "wb");
	if (fp == NULL) {printf("open error\r\n");}
	
	difinition();
	sort();
	clear();
	graph();
	header();
	footer();
	hit();
	fixed();
	
	fclose(fp);
}

/*------------------------------------------------------------------------------
	書式：void difinition(void)
	機能：定義部分を出力
------------------------------------------------------------------------------*/
void difinition(void)
{
	INT32 i;
	INT32 cnt;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  色");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("DEFINE, RGB_BLACK,  000000");
	PRINT("DEFINE, RGB_GRAY,   C0C0C0");
	PRINT("DEFINE, RGB_RED,    F00000");
	PRINT("DEFINE, RGB_GREEN,  00F000");
	PRINT("DEFINE, RGB_BLUE,   0000F0");
	PRINT("DEFINE, RGB_MAZENTA,F000F0");
	PRINT("DEFINE, RGB_YELLOW, F0F000");
	PRINT("DEFINE, RGB_CYAN,   00F0F0");
	PRINT("DEFINE, RGB_AVE100, F0F0F0");
	PRINT("DEFINE, RGB_AVE75,  A0A0F0");
	PRINT("DEFINE, RGB_AVE25,  F0A0A0");
	PRINT("DEFINE, RGB_AVE5,   A0F0A0");
	PRINT("");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  座標");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("DEFINE, DAYS,      %d", DAYS);
	PRINT("DEFINE, MAX,       %d", MAX);
	PRINT("DEFINE, MIN,       %d", MIN);
	PRINT("DEFINE, RANGE,     %d", RANGE);
	PRINT("DEFINE, X1,        77");
	PRINT("DEFINE, Y1,        255");
	PRINT("DEFINE, X2,        767");
	PRINT("DEFINE, Y2,        863");
	PRINT("DEFINE, W,         (X2-X1)");
	PRINT("DEFINE, H,         (Y2-Y1)");
	PRINT("DEFINE, X_SCALE,   30");
	PRINT("DEFINE, Y_WEEKEND, (Y2+5)");
	
	cnt = (MAX-MIN)/STEP1;
	for (i = 0; i <= cnt; i++) {
		PRINT("DEFINE, Y_%d,     (((H*%2d)/%d)+Y1)",  MAX-STEP1*i, i, cnt);
	}
	
	PRINT("DEFINE, gX,        (X1+18)");
	PRINT("DEFINE, gW,        (W-18*2)");
	PRINT("DEFINE, tX1,       X1");
	PRINT("DEFINE, tY1,       910");
	PRINT("DEFINE, tX2,       X2");
	PRINT("DEFINE, tY2,       1030");
	PRINT("DEFINE, tW,        W");
	PRINT("DEFINE, tH,        (tY2-tY1)");
	PRINT("DEFINE, tMAX,      6000");
	PRINT("DEFINE, tMIN,      0");
	PRINT("DEFINE, tRANGE,    60000000");
	PRINT("DEFINE, tX_SCALE,  30");
	PRINT("DEFINE, tY_6000,   (((tH*0)/6)+tY1)");
	PRINT("DEFINE, tY_5000,   (((tH*1)/6)+tY1)");
	PRINT("DEFINE, tY_4000,   (((tH*2)/6)+tY1)");
	PRINT("DEFINE, tY_3000,   (((tH*3)/6)+tY1)");
	PRINT("DEFINE, tY_2000,   (((tH*4)/6)+tY1)");
	PRINT("DEFINE, tY_1000,   (((tH*5)/6)+tY1)");
	PRINT("DEFINE, tY_0000,   (((tH*6)/6)+tY1)");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void sort(void)
	機能：並び変える
------------------------------------------------------------------------------*/
void sort(void)
{
	INT32 i, j;
	INT32 cnt;
	
	for (i = 0; i < CNT; i++) {tmp[i] = field[CNT-1-i];}
	
	for (i = 0; i < CNT; i++) {
		ave5 [i] = 0.0;
		ave25[i] = 0.0;
		ave75[i] = 0.0;
		ave100[i] = 0.0;
		
		if (4 <= i) {
			for (j = 0; j < 5; j++) {
				ave5[i] += tmp[i-j].end;
			}
			ave5[i] /= 5;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave5[i] += tmp[i-j].end;
			}
			ave5[i] /= cnt;
		}
		
		if (24 <= i) {
			for (j = 0; j < 25; j++) {
				ave25[i] += tmp[i-j].end;
			}
			ave25[i] /= 25;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave25[i] += tmp[i-j].end;
			}
			ave25[i] /= cnt;
		}
		
		if (74 <= i) {
			for (j = 0; j < 75; j++) {
				ave75[i] += tmp[i-j].end;
			}
			ave75[i] /= 75;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave75[i] += tmp[i-j].end;
			}
			ave75[i] /= cnt;
		}
		
		if (99 <= i) {
			for (j = 0; j < 100; j++) {
				ave100[i] += tmp[i-j].end;
			}
			ave100[i] /= 100;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave100[i] += tmp[i-j].end;
			}
			ave100[i] /= cnt;
		}
	}
}

/*------------------------------------------------------------------------------
	書式：void claer(void)
	機能：塗りつぶす
------------------------------------------------------------------------------*/
void clear(void)
{
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  塗りつぶし");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("RECT, 0, 0, 840, 1050, 000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void graph(void)
	機能：グラフ部分を出力
------------------------------------------------------------------------------*/
void graph(void)
{
	INT32 i;
	INT8 fmt1[150+1] = "MOVETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f-MIN))/RANGE), %s";
	INT8 fmt2[150+1] = "LINETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f-MIN))/RANGE)";
	INT8 fmt3[150+1] = "DEFINE, GY%02X_%s, (Y2-((H*(%.1f-MIN))/RANGE))";
	INT8 fmt4[150+1] = "DEFINE, GH%02X,     ((H*(%.1f-%.1f))/RANGE)";
	INT8 fmt5[150+1] = "DEFINE, GH%02X,     %d";
	INT8 fmt6[150+1] = "RECT, X1+(W*%2d)/(DAYS+1), GY%02X_%s, 7, GH%02X, 000000, %s 1, 0, FALSE, TRUE, FALSE, FALSE";
	INT8 fmt7[150+1] = "LINE, X1+(W*%2d)/(DAYS+1)+3, GY%02X_MAX, X1+(W*%2d)/(DAYS+1)+3, GY%02X_MIN, %s 1";
	INT8 fmt8[150+1] = "MOVETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f%+.1f* 1-MIN))/RANGE), %s";
	INT8 fmt9[150+1] = "LINETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f%+.1f*%2d-MIN))/RANGE)";
	INT32 dt;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  グラフ");
	PRINT(":-------------------------------------------------------------------------------");
	
	for (i = 0; (MIN+STEP2*i) <= MAX; i++) {
		PRINT("LINE, X1+1, Y_%d, X2-1, Y_%d, RGB_GRAY, 1", MIN+STEP2*i,
														   MIN+STEP2*i);
	}
	PRINT("");
	
	for (i = 0; (MIN+STEP1*i) <= MAX; i++) {
		PRINT("LINE, X1, Y_%d, X1+4, Y_%d, RGB_BLACK, 1", MIN+STEP1*i,
														  MIN+STEP1*i);
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave100[i], "RGB_AVE100, 7");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave100[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave75[i], "RGB_AVE75, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave75[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave25[i], "RGB_AVE25, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave25[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave5[i], "RGB_AVE5, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave5[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			PRINT(fmt3, dt, "STA", tmp[i].sta);
			PRINT(fmt3, dt, "MAX", tmp[i].max);
			PRINT(fmt3, dt, "MIN", tmp[i].min);
			PRINT(fmt3, dt, "END", tmp[i].end);
			
			if (tmp[i].end >= tmp[i].sta) {
				if ((INT32)((608*(tmp[i].end-tmp[i].sta))/RANGE) == 0) {
					PRINT(fmt5, dt, 1);
				}
				else {
					PRINT(fmt4, dt, tmp[i].end, tmp[i].sta);
				}
			}
			else {
				if ((INT32)((608*(tmp[i].sta-tmp[i].end))/RANGE) == 0) {
					PRINT(fmt5, dt, 1);
				}
				else {
					PRINT(fmt4, dt, tmp[i].sta, tmp[i].end);
				}
			}
			PRINT("");
		}
	}
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			if (tmp[i].end >= tmp[i].sta) {PRINT(fmt6, i-(CNT-OUT)+1, dt, "END", dt, "RGB_RED, ");}
			else                          {PRINT(fmt6, i-(CNT-OUT)+1, dt, "STA", dt, "RGB_BLUE,");}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			if (tmp[i].end >= tmp[i].sta) {PRINT(fmt7, i-(CNT-OUT)+1, dt, i-(CNT-OUT)+1, dt, "RGB_RED, ");}
			else                          {PRINT(fmt7, i-(CNT-OUT)+1, dt, i-(CNT-OUT)+1, dt, "RGB_BLUE,");}
		}
	}
	PRINT("");
	
	if ((OUT+1) < DAYS) {
		PRINT(fmt8, OUT+1, ave100[CNT-1], ave100[CNT-1]-ave100[CNT-2], "RGB_AVE100, 7");
		PRINT(fmt9, DAYS,  ave100[CNT-1], ave100[CNT-1]-ave100[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave75[CNT-1], ave75[CNT-1]-ave75[CNT-2], "RGB_AVE75, 2");
		PRINT(fmt9, DAYS,  ave75[CNT-1], ave75[CNT-1]-ave75[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave25[CNT-1], ave25[CNT-1]-ave25[CNT-2], "RGB_AVE25, 2");
		PRINT(fmt9, DAYS,  ave25[CNT-1], ave25[CNT-1]-ave25[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave5[CNT-1], ave5[CNT-1]-ave5[CNT-2], "RGB_AVE5, 2");
		PRINT(fmt9, DAYS,  ave5[CNT-1], ave5[CNT-1]-ave5[CNT-2], DAYS-OUT);
		
		PRINT("");
	}
	
	PRINT("RECT, 0,   0,   840,     Y1,       000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, 0,   Y2+1,840,     1050-Y2-1,000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, 0,   0,   X1,      1050,     000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, X2+1,0,   840-X2-1,1050,     000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("");
	PRINT("LINE, X1, Y1, X2, Y1, RGB_BLACK, 1");
	PRINT("LINE, X1, Y1, X1, Y2, RGB_BLACK, 1");
	PRINT("LINE, X2, Y1, X2, Y2, RGB_BLACK, 1");
	PRINT("LINE, X1, Y2, X2, Y2, RGB_BLACK, 1");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void header(void)
	機能：ヘッダー部分を出力
------------------------------------------------------------------------------*/
void header(void)
{
	char fmt1[100+1] = "TEXT, 319, 25 ,5020 ENEOS 20%02X年%2X月, RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt2[100+1] = "TEXT, 95,  100,%.1f,                 RGB_BLACK, 000000, TRUE, Arial, 70, FALSE";
	char fmt3[100+1] = "TEXT, 75,  185,20%02X/%02X/%02X 15:00 現在, RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt4[100+1] = "TEXT, 333, 130,%s,     RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt5[100+1] = "TEXT, 333, 162,%s,     RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt6[100+1] = "TEXT, 455, 193,%.2f%,                 RGB_BLACK, 000000, TRUE, Arial, 30, FALSE";
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  ヘッダー");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("RECT, 45,  70,  250, 160, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("RECT, 49,  74,  242, 152, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("RECT, 320, 120, 220, 110, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("");
	
	if (tmp[CNT-1].end == 0) {printf("0 div error\r\n");}
	
	PRINT(fmt1, (tmp[CNT-1].date & 0x00FF0000)>>16,
	            (tmp[CNT-1].date & 0x0000FF00)>> 8);
	PRINT(fmt2, tmp[CNT-1].end);
	PRINT(fmt3, (tmp[CNT-1].date & 0x00FF0000)>>16,
	            (tmp[CNT-1].date & 0x0000FF00)>> 8,
	            (tmp[CNT-1].date & 0x000000FF)>> 0);
	PRINT(fmt4, "11円　2023年3月末");
	PRINT(fmt5, "11円　2023年9月末");
	PRINT(fmt6, (22/tmp[CNT-1].end)*100);
	
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void footer(void)
	機能：フッター部分を出力
------------------------------------------------------------------------------*/
void footer(void)
{
	INT32 i;
	INT8 fmt1[150+1] = "RECT, X1+(W*%2d)/(DAYS+1), tY2, 6, -(tH*%8d)/tRANGE, 000000, %s 1, 0, FALSE, TRUE, FALSE, FALSE";
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  フッター");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("LINE, X1,   tY_6000, X2,   tY_6000, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_4000, X2,   tY_4000, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_2000, X2,   tY_2000, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_0000, X2,   tY_0000, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_5000, X1+4, tY_5000, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_3000, X1+4, tY_3000, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_1000, X1+4, tY_1000, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_5000, X2,   tY_5000, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_3000, X2,   tY_3000, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_1000, X2,   tY_1000, RGB_GRAY, 1");
	PRINT("");
	PRINT("TEXT, tX_SCALE,    (tY_6000-10),6000, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE,    (tY_4000-10),4000, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE,    (tY_2000-10),2000, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE+27, (tY_0000-10),0,    RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (tmp[i].ratio > 0) {
				PRINT(fmt1, i-(CNT-OUT)+1, tmp[i].trade, "RGB_RED, ");
			}
			else {
				PRINT(fmt1, i-(CNT-OUT)+1, tmp[i].trade, "RGB_BLUE,");
			}
		}
	}
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void hit(void)
	機能：出現率を出力
------------------------------------------------------------------------------*/
void hit(void)
{
	INT32 i;
	INT32 rate[31] = {0};
	INT32 pos;
	INT32 max = 0;
	INT8 fmt1[200] = "RECT, 62+6-%d, (Y_%d-%d), %d*2, %d*2, 000000, RGB_BLACK, 1, 0, FALSE, TRUE, TRUE, FALSE";
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  出現率");
	PRINT(":-------------------------------------------------------------------------------");
	
	for (i = 0; i < CNT; i++) {
		pos = (tmp[i].end - MIN) / 5;
		
		if (pos < 0)  {continue;}
		if (pos > 30) {continue;}
		
		rate[pos]++;
	}
	
	for (i = 0; i < 31; i++) {
		if (rate[i] >max) {max = rate[i];}
	}
	
	for (i = 0; i < 31; i++) {
		pos = MIN+i*5;
		
		if (rate[i] == 0) {
		}
		else if (rate[i] <= ((max*1)/5)) {
			PRINT(fmt1, 1, pos, 1, 1, 1);
		}
		else if (rate[i] <= ((max*2)/5)) {
			PRINT(fmt1, 2, pos, 2, 2, 2);
		}
		else if (rate[i] <= ((max*3)/5)) {
			PRINT(fmt1, 3, pos, 3, 3, 3);
		}
		else if (rate[i] <= ((max*4)/5)) {
			PRINT(fmt1, 4, pos, 4, 4, 4);
		}
		else if (rate[i] <= ((max*5)/5)) {
			PRINT(fmt1, 5, pos, 5, 5, 5);
		}
	}
	PRINT("");
	
	INT8 fmt2[150+1] = "TEXT, 642, 35,平均絶対値　%.1f円, RGB_BLACK, 000000, TRUE, Arial, 16, FALSE";
	double aveAbs;
	
	aveAbs = 0.0;
	for (i = 0; i < OUT; i++) {
		aveAbs+= abs(tmp[CNT-1-i].ratio);
	}
	
	if (OUT != 0) {
		aveAbs /= OUT;
		PRINT(fmt2, aveAbs);
	}
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void fixed(void)
	機能：固定部分を出力
------------------------------------------------------------------------------*/
void fixed(void)
{
	INT32 i;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  固定");
	PRINT(":-------------------------------------------------------------------------------");
	
	for (i = 0; (MIN+STEP2*i) <= MAX; i++) {
		PRINT("TEXT, X_SCALE,(Y_%d-10),%d, RGB_BLACK, 000000, TRUE, ＭＳ ゴシック, 20, FALSE", MIN+STEP2*i,
																							   MIN+STEP2*i);
	}
	PRINT("");
	
	PRINT("DEFINE, Y_3.25, (Y2-((H*(676.92-MIN))/RANGE))");
	PRINT("DEFINE, Y_3.50, (Y2-((H*(628.57-MIN))/RANGE))");
	PRINT("DEFINE, Y_3.75, (Y2-((H*(586.66-MIN))/RANGE))");
	PRINT("DEFINE, Y_4.00, (Y2-((H*(550.00-MIN))/RANGE))");
	PRINT("DEFINE, Y_4.25, (Y2-((H*(517.64-MIN))/RANGE))");
	PRINT("DEFINE, Y_4.50, (Y2-((H*(488.88-MIN))/RANGE))");
	PRINT("DEFINE, Y_4.75, (Y2-((H*(463.15-MIN))/RANGE))");
	PRINT("DEFINE, Y_5.00, (Y2-((H*(440.00-MIN))/RANGE))");
	PRINT("DEFINE, Y_5.25, (Y2-((H*(419.04-MIN))/RANGE))");
	PRINT("DEFINE, Y_5.50, (Y2-((H*(400.00-MIN))/RANGE))");
	PRINT("");
//	PRINT("LINE, X2-4, Y_3.25, X2, Y_3.25, RGB_BLACK, 1");
//	PRINT("LINE, X2-4, Y_3.50, X2, Y_3.50, RGB_BLACK, 1");
	PRINT("LINE, X2-4, Y_3.75, X2, Y_3.75, RGB_BLACK, 1");
	PRINT("LINE, X2-4, Y_4.00, X2, Y_4.00, RGB_BLACK, 1");
	PRINT("LINE, X2-4, Y_4.25, X2, Y_4.25, RGB_BLACK, 1");
	PRINT("LINE, X2-4, Y_4.50, X2, Y_4.50, RGB_BLACK, 1");
//	PRINT("LINE, X2-4, Y_4.75, X2, Y_4.75, RGB_BLACK, 1");
//	PRINT("LINE, X2-4, Y_5.00, X2, Y_5.00, RGB_BLACK, 1");
//	PRINT("LINE, X2-4, Y_5.25, X2, Y_5.25, RGB_BLACK, 1");
//	PRINT("LINE, X2-4, Y_5.50, X2, Y_5.50, RGB_BLACK, 1");
	PRINT("");
//	PRINT("TEXT, 775,(Y_3.25-6),3.25, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
//	PRINT("TEXT, 775,(Y_3.50-6),3.50, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
	PRINT("TEXT, 775,(Y_3.75-6),3.75, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
	PRINT("TEXT, 775,(Y_4.00-6),4.00, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
	PRINT("TEXT, 775,(Y_4.25-6),4.25, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
	PRINT("TEXT, 775,(Y_4.50-6),4.50, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
//	PRINT("TEXT, 775,(Y_4.75-6),4.75, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
//	PRINT("TEXT, 775,(Y_5.00-6),5.00, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
//	PRINT("TEXT, 775,(Y_5.25-6),5.25, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
//	PRINT("TEXT, 775,(Y_5.50-6),5.50, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE");
	
//	PRINT("");
//	PRINT("TEXT,10,10,-25,RGB_BLUE,000000,TRUE,Arial,30,FALSE");
}

/*------------------------------------------------------------------------------
	書式：void fprintf_crlf(char *pStr, ...)
	引数：char *  -
	      ...     -
	機能：出力
------------------------------------------------------------------------------*/
void fprintf_crlf(char *pStr, ...)
{
	va_list args;
	
	va_start(args, pStr);
	
	vfprintf(fp, pStr, args);
	fprintf(fp, "\r\n");
	
	va_end(args); 
}

/*------------------------------------------------------------------------------
	実体
------------------------------------------------------------------------------*/
Field field[CNT] = {
	{0x231114,	554.2,	563.0,	554.1,	563.0,	+15.8,	16702100,},
	{0x231113,	548.0,	552.0,	545.0,	547.2,	 +2.4,	14688000,},
	{0x231110,	536.0,	544.8,	530.9,	544.8,	 +8.7,	15269700,},
	{0x231109,	528.5,	538.4,	521.8,	536.1,	 +8.8,	25479000,},
	{0x231108,	557.4,	559.3,	527.3,	527.3,	-38.8,	47448800,},
	{0x231107,	568.8,	571.9,	564.2,	566.1,	 -0.2,	15325300,},
	{0x231106,	569.0,	569.8,	563.8,	566.3,	 +0.3,	13019200,},
	{0x231102,	570.1,	578.2,	564.2,	566.0,	 -2.5,	13835700,},
	{0x231101,	563.8,	569.7,	562.1,	568.5,	+10.8,	12842000,},
	{0x231031,	550.2,	561.0,	549.8,	557.7,	 +4.8,	14319600,},
	{0x231030,	551.0,	556.2,	549.5,	552.9,	 -3.9,	37890100,},
	{0x231027,	546.6,	558.0,	546.5,	556.8,	+12.0,	11892900,},
	{0x231026,	551.7,	554.4,	543.0,	544.8,	 -6.9,	14226700,},
	{0x231025,	540.3,	556.8,	538.7,	551.7,	 +6.7,	15587400,},
	{0x231024,	544.5,	547.9,	534.4,	545.0,	 -3.0,	15733800,},
	{0x231023,	561.6,	561.6,	548.0,	548.0,	-17.0,	15502200,},
	{0x231020,	561.5,	568.7,	556.5,	565.0,	 +4.4,	20297000,},
	{0x231019,	559.8,	567.8,	557.8,	560.6,	 -1.9,	15596400,},
	{0x231018,	555.1,	564.2,	554.4,	562.5,	+10.1,	15616700,},
	{0x231017,	557.6,	562.9,	551.1,	552.4,	 -3.7,	13601500,},
	{0x231016,	560.6,	564.9,	553.0,	556.1,	+10.3,	25890200,},
	{0x231013,	550.5,	551.1,	542.9,	545.8,	 -5.9,	15647100,},
	{0x231012,	545.0,	554.0,	541.1,	551.7,	 +1.6,	21374000,},
	{0x231011,	551.3,	556.1,	548.4,	550.1,	 +0.9,	19017600,},
	{0x231010,	559.0,	560.8,	545.3,	549.2,	+27.2,	34903700,},
	{0x231006,	521.7,	529.9,	513.8,	522.0,	 -3.5,	21350600,},
	{0x231005,	513.1,	528.7,	509.5,	525.5,	 +4.3,	25934600,},
	{0x231004,	541.1,	542.5,	521.2,	521.2,	-20.4,	24306100,},
	{0x231003,	560.0,	560.3,	540.1,	541.6,	-33.7,	32525700,},
	{0x231002,	585.8,	591.3,	573.6,	575.3,	-14.6,	18916000,},
	{0x230929,	596.8,	598.8,	582.3,	589.9,	-16.8,	23748700,},
	{0x230928,	620.2,	622.3,	604.4,	606.7,	-12.0,	22170700,},
	{0x230927,	612.4,	618.8,	608.1,	618.7,	 +4.5,	18361300,},
	{0x230926,	616.0,	616.8,	608.7,	614.2,	 -1.5,	15200100,},
	{0x230925,	619.0,	619.6,	611.2,	615.7,	 -3.1,	12276500,},
	{0x230922,	610.1,	623.7,	606.6,	618.8,	 +3.3,	21992100,},
	{0x230921,	614.1,	626.5,	613.2,	615.5,	 -2.1,	20058000,},
	{0x230920,	637.7,	638.9,	615.3,	617.6,	-20.0,	31995400,},
	{0x230919,	630.0,	638.8,	625.1,	637.6,	 +5.7,	23840700,},
	{0x230915,	621.4,	642.3,	620.4,	631.9,	+19.7,	43269200,},
	{0x230914,	595.0,	613.1,	594.5,	612.2,	+20.7,	26316500,},
	{0x230913,	593.0,	598.3,	588.9,	591.5,	 +7.0,	17842400,},
	{0x230912,	584.0,	585.1,	577.9,	584.5,	 +1.9,	13947600,},
	{0x230911,	586.1,	588.4,	582.1,	582.6,	 +3.8,	10644500,},
	{0x230908,	580.4,	589.4,	575.5,	578.8,	 -3.8,	18560100,},
	{0x230907,	577.0,	584.8,	576.5,	582.6,	 +8.4,	16907400,},
	{0x230906,	570.0,	581.5,	570.0,	574.2,	 +7.9,	20069500,},
	{0x230905,	567.3,	567.6,	559.7,	566.3,	 +1.1,	12040400,},
	{0x230904,	561.7,	565.6,	556.3,	565.2,	 +8.6,	16512300,},
	{0x230901,	545.0,	558.0,	543.9,	556.6,	+10.3,	20399600,},
	{0x230831,	544.0,	547.8,	543.2,	546.3,	 +2.4,	17250500,},
	{0x230830,	540.0,	545.4,	538.3,	543.9,	 +5.9,	13374000,},
	{0x230829,	539.1,	540.7,	535.7,	538.0,	 +0.9,	 8710100,},
	{0x230827,	531.0,	538.5,	531.0,	537.1,	+12.4,	14309100,},
	{0x230825,	525.3,	525.5,	520.3,	524.7,	 -1.3,	10124400,},
	{0x230824,	523.9,	529.8,	522.6,	526.0,	 +5.3,	13350200,},
	{0x230823,	521.0,	525.4,	519.3,	520.7,	 -1.3,	 9795500,},
	{0x230822,	513.9,	522.4,	512.5,	522.0,	 +8.4,	10566000,},
	{0x230821,	514.4,	520.2,	513.6,	513.6,	 +1.9,	10301600,},
	{0x230818,	514.0,	517.0,	509.7,	511.7,	 +0.6,	14018900,},
	{0x230817,	514.9,	515.2,	504.9,	511.1,	 -4.8,	13713800,},
	{0x230816,	522.0,	523.2,	513.7,	515.9,	-16.1,	17562500,},
	{0x230815,	538.0,	540.6,	531.3,	532.0,	 -5.0,	15362600,},
	{0x230814,	548.0,	548.0,	536.1,	537.0,	-12.8,	19964700,},
	{0x230810,	527.0,	549.8,	526.2,	549.8,	+28.7,	56043400,},
	{0x230809,	529.7,	530.0,	519.3,	521.1,	 -7.0,	13172500,},
	{0x230808,	528.5,	531.4,	525.1,	528.1,	 +2.0,	16096700,},
	{0x230807,	520.0,	528.5,	519.1,	526.1,	 +8.6,	16548400,},
	{0x230804,	510.2,	517.9,	510.1,	517.5,	 +3.1,	10377700,},
	{0x230803,	516.2,	518.3,	513.2,	514.4,	 -3.1,	13966900,},
	{0x230802,	518.1,	522.3,	515.4,	517.5,	 -3.5,	11211900,},
	{0x230801,	517.0,	521.7,	516.1,	521.0,	 +5.6,	12732700,},
	{0x230731,	516.7,	517.9,	513.2,	515.4,	 +2.5,	16235100,},
	{0x230728,	511.0,	513.2,	506.1,	512.9,	 -0.1,	15784000,},
	{0x230727,	511.6,	515.0,	510.5,	513.0,	 +3.1,	15179500,},
	{0x230726,	514.8,	514.8,	508.3,	509.9,	 -2.6,	13025300,},
	{0x230725,	507.6,	514.8,	507.0,	512.5,	+10.1,	21031100,},
	{0x230724,	498.5,	507.4,	498.2,	502.4,	 +5.5,	16341500,},
	{0x230721,	496.4,	497.5,	493.7,	496.9,	 +2.7,	 8888600,},
	{0x230720,	496.9,	497.9,	493.7,	494.2,	 -0.2,	 8039200,},
	{0x230719,	492.4,	494.9,	490.5,	494.4,	 +6.5,	10955700,},
	{0x230718,	489.6,	490.9,	486.8,	487.9,	 -3.7,	10982600,},
	{0x230714,	492.6,	494.3,	489.8,	491.6,	 -2.4,	 9780800,},
	{0x230713,	494.1,	496.2,	492.0,	494.0,	 +1.8,	 9574700,},
	{0x230712,	495.5,	496.3,	490.7,	492.2,	 -1.3,	 9066200,},
	{0x230711,	498.0,	498.0,	493.0,	493.5,	 -1.5,	 8908000,},
	{0x230710,	499.0,	502.5,	494.6,	495.0,	 -1.9,	15150800,},
	{0x230707,	496.7,	501.3,	493.6,	496.9,	 -1.7,	13567300,},
	{0x230706,	503.9,	505.1,	497.1,	498.6,	 -5.0,	15192300,},
	{0x230705,	502.3,	503.6,	498.3,	503.6,	 +1.3,	12128700,},
	{0x230704,	505.0,	505.0,	501.3,	502.3,	 -2.6,	11872000,},
	{0x230703,	495.2,	505.0,	495.1,	504.9,	+10.5,	20651300,},
	{0x230630,	497.0,	497.0,	492.4,	494.4,	 -2.5,	21770100,},
	{0x230629,	498.6,	498.9,	492.9,	496.9,	 +0.9,	14314300,},
	{0x230628,	489.1,	496.1,	488.3,	496.0,	 +4.1,	15837400,},
	{0x230627,	486.8,	492.9,	485.6,	491.9,	 +6.6,	17701100,},
	{0x230626,	485.0,	488.5,	483.0,	485.3,	 +2.5,	12367600,},
	{0x230623,	484.5,	486.4,	481.7,	482.8,	 -1.9,	14403300,},
	{0x230622,	485.3,	489.9,	484.6,	484.7,	 +3.0,	16031900,},
	{0x230621,	480.0,	482.6,	477.8,	481.7,	 -0.2,	13679200,},
	{0x230620,	487.2,	488.0,	480.4,	481.9,	 -5.2,	16489000,},
	{0x230619,	491.7,	493.0,	484.8,	487.1,	 +0.4,	13895400,},
	{0x230616,	485.0,	488.7,	484.0,	486.7,	 +3.0,	23259200,},
	{0x230615,	482.8,	486.3,	480.5,	483.7,	 -0.1,	10134900,},
	{0x230614,	483.0,	487.3,	482.8,	483.8,	 +3.2,	15910300,},
	{0x230613,	480.1,	481.9,	478.6,	480.6,	 -1.8,	13113700,},
	{0x230612,	482.5,	484.2,	480.1,	482.4,	 +0.8,	10678500,},
	{0x230609,	482.6,	483.0,	480.5,	481.6,	 -1.1,	17986600,},
	{0x230608,	484.4,	488.0,	480.4,	482.7,	 +3.6,	14201200,},
	{0x230607,	485.0,	487.8,	478.8,	479.1,	 -4.6,	22758900,},
	{0x230606,	477.4,	483.7,	475.4,	483.7,	 +5.1,	16348600,},
	{0x230605,	480.0,	482.3,	476.6,	478.6,	+10.0,	20202400,},
	{0x230602,	468.0,	469.0,	464.2,	468.6,	 +2.8,	11962300,},
	{0x230601,	462.3,	466.5,	462.0,	465.8,	 +2.0,	11825700,},
	{0x230531,	470.7,	470.8,	463.8,	463.8,	-10.2,	49003800,},
	{0x230530,	476.3,	476.3,	471.2,	475.3,	 -1.2,	10773400,},
	{0x230529,	474.0,	477.7,	472.8,	476.5,	 +4.2,	 9659200,},
	{0x230526,	476.6,	477.5,	471.5,	472.3,	 -6.3,	13534800,},
	{0x230525,	477.6,	479.5,	476.5,	479.1,	 +0.2,	10081000,},
	{0x230524,	475.0,	480.3,	474.6,	478.9,	 +6.6,	16414800,},
	{0x230523,	471.2,	474.8,	468.4,	472.3,	 -1.4,	22107600,},
	{0x230522,	471.5,	476.0,	471.5,	473.7,	 +3.5,	15153700,},
	{0x230519,	476.5,	477.2,	469.8,	470.2,	 -5.5,	23387100,},
	{0x230518,	483.2,	484.3,	475.7,	475.7,	 -1.2,	16284800,},
	{0x230517,	480.0,	480.1,	475.0,	476.9,	 -5.5,	15882300,},
	{0x230516,	488.0,	489.8,	481.0,	482.4,	 -2.6,	13658100,},
	{0x230515,	492.0,	493.2,	484.1,	485.0,	 -5.2,	17567500,},
	{0x230512,	503.0,	504.4,	487.8,	490.2,	-15.8,	24493400,},
	{0x230511,	486.0,	507.0,	484.9,	506.0,	+25.6,	51687900,},
	{0x230510,	482.6,	484.4,	480.1,	480.4,	 -2.5,	16223100,},
	{0x230509,	482.7,	483.6,	481.4,	482.9,	 +3.1,	11439900,},
	{0x230508,	482.1,	482.4,	475.7,	479.8,	 -4.3,	13461300,},
	{0x230502,	487.0,	488.0,	482.0,	484.1,	 -1.6,	10392200,},
	{0x230501,	487.0,	488.8,	483.6,	485.7,	 +3.7,	13786400,},
	{0x230428,	478.0,	482.6,	477.8,	482.0,	 +5.2,	18588600,},
	{0x230427,	473.5,	476.8,	472.5,	476.8,	 +1.2,	11964200,},
	{0x230426,	472.0,	475.9,	470.4,	475.6,	 +0.2,	13854000,},
	{0x230425,	477.0,	477.7,	473.5,	475.4,	 +1.3,	 9288100,},
	{0x230424,	473.4,	475.9,	472.1,	474.1,	 +1.8,	 7991000,},
	{0x230421,	473.8,	475.8,	472.2,	472.3,	 -1.6,	 9242700,},
	{0x230420,	473.0,	475.6,	471.8,	473.9,	 -2.8,	 8865600,},
	{0x230419,	475.2,	477.8,	474.8,	476.7,	 +2.7,	10219100,},
	{0x230418,	474.1,	475.2,	471.6,	474.0,	 -1.8,	10001100,},
	{0x230417,	480.0,	480.4,	473.9,	475.8,	 -2.5,	 9196700,},
	{0x230414,	473.8,	479.0,	471.8,	478.3,	 +7.6,	18182400,},
	{0x230413,	472.5,	473.9,	468.2,	470.7,	 -3.0,	10761400,},
	{0x230412,	473.7,	475.3,	470.0,	473.7,	 +2.5,	12388200,},
	{0x230411,	463.7,	472.0,	463.3,	471.2,	 +8.2,	13241000,},
	{0x230410,	463.0,	465.0,	461.8,	463.0,	 +2.5,	 9044100,},
	{0x230407,	461.6,	463.3,	460.5,	460.5,	 -1.7,	 9963300,},
	{0x230406,	466.2,	466.7,	461.8,	462.2,	 -8.2,	15304500,},
	{0x230405,	477.0,	477.6,	469.5,	470.4,	-13.3,	15588500,},
	{0x230404,	484.0,	485.0,	477.7,	483.7,	 +3.4,	18046000,},
	{0x230403,	474.7,	485.0,	472.7,	480.3,	+15.1,	34642100,},
	{0x230331,	463.0,	466.7,	462.0,	465.2,	 +5.6,	19536000,},
	{0x230330,	461.6,	461.7,	456.5,	459.6,	-15.4,	45243100,},
	{0x230329,	471.5,	475.0,	469.0,	475.0,	 +7.7,	22005100,},
	{0x230328,	469.1,	472.7,	465.8,	467.3,	 +3.0,	15448300,},
	{0x230327,	465.5,	466.1,	461.2,	464.3,	 +2.3,	10572500,},
	{0x230324,	459.0,	462.9,	458.2,	462.0,	 -1.9,	11045100,},
	{0x230323,	458.0,	464.3,	455.4,	463.9,	 +3.6,	12990400,},
	{0x230322,	461.4,	461.5,	457.3,	460.3,	 +6.9,	15693600,},
	{0x230320,	450.6,	457.4,	449.4,	453.4,	 -1.1,	13121200,},
	{0x230317,	456.0,	456.6,	451.4,	454.5,	 -1.9,	21347500,},
	{0x230316,	451.0,	457.6,	449.0,	456.4,	 -7.1,	21232600,},
	{0x230315,	462.9,	465.3,	461.2,	463.5,	 +3.9,	13259000,},
	{0x230314,	464.1,	464.9,	457.4,	459.6,	-12.5,	25859300,},
	{0x230313,	472.4,	473.7,	468.7,	472.1,	 -3.8,	14109000,},
	{0x230310,	476.0,	480.3,	475.7,	475.9,	 -8.1,	19249700,},
	{0x230309,	483.4,	485.6,	483.1,	484.0,	 +1.5,	12818400,},
	{0x230308,	480.0,	483.7,	478.5,	482.5,	 -0.1,	13313300,},
	{0x230307,	475.8,	483.0,	475.6,	482.6,	 +5.4,	17535600,},
	{0x230306,	479.9,	480.0,	476.5,	477.2,	 +0.2,	12979100,},
	{0x230303,	477.6,	479.2,	476.3,	477.0,	 +1.2,	16818400,},
	{0x230302,	480.0,	482.3,	474.7,	475.8,	 -2.0,	17622400,},
	{0x230301,	471.2,	477.8,	471.2,	477.8,	 +7.5,	17598000,},
	{0x230228,	471.0,	473.9,	468.3,	470.3,	 +1.5,	17701300,},
	{0x230227,	467.2,	470.4,	466.9,	468.8,	 +5.1,	14483100,},
	{0x230224,	464.7,	465.4,	462.3,	463.7,	 -0.4,	11115700,},
	{0x230222,	468.2,	469.0,	463.6,	464.1,	 -7.0,	14312900,},
	{0x230221,	461.3,	472.1,	459.3,	471.1,	 +8.5,	19433800,},
	{0x230220,	459.4,	463.3,	456.8,	462.6,	 +3.2,	14622800,},
	{0x230217,	460.2,	460.9,	458.0,	459.4,	 -1.2,	14115900,},
	{0x230216,	459.7,	461.2,	458.7,	460.6,	 +0.9,	10706100,},
	{0x230215,	462.5,	463.5,	458.7,	459.7,	 -2.8,	17653600,},
	{0x230214,	462.0,	463.5,	459.2,	462.5,	 +4.5,	10045900,},
	{0x230213,	461.6,	464.0,	458.0,	458.0,	 +1.6,	16788700,},
	{0x230210,	465.0,	465.3,	455.1,	456.4,	-10.7,	28871200,},
	{0x230209,	462.6,	467.6,	461.9,	467.1,	 +3.9,	10633100,},
	{0x230208,	465.7,	467.1,	460.8,	463.2,	 +3.2,	11409600,},
	{0x230207,	464.4,	465.8,	460.0,	460.0,	 -1.8,	12003600,},
	{0x230206,	456.9,	461.8,	456.4,	461.8,	 +9.2,	14599600,},
	{0x230203,	454.0,	457.0,	450.5,	452.6,	 -5.9,	13815000,},
	{0x230202,	462.4,	462.4,	457.6,	458.5,	 -5.5,	13926700,},
	{0x230201,	466.1,	470.0,	463.8,	464.0,	 +0.8,	 8972500,},
	{0x230131,	464.0,	468.4,	463.2,	463.2,	 -5.3,	13480400,},
	{0x230130,	473.3,	473.6,	466.9,	468.5,	 -7.7,	15359300,},
	{0x230127,	478.0,	478.3,	475.0,	476.2,	 +1.2,	 7538200,},
	{0x230126,	477.4,	478.5,	474.7,	475.0,	 -2.2,	11807500,},
	{0x230125,	475.2,	477.3,	473.8,	477.2,	 +0.9,	10023700,},
	{0x230124,	473.0,	479.0,	472.5,	476.3,	 +5.2,	14794600,},
	{0x230123,	470.4,	473.3,	470.3,	471.1,	 +3.0,	12606600,},
	{0x230120,	466.1,	468.3,	464.6,	468.1,	 +5.5,	11550400,},
	{0x230119,	464.8,	465.4,	460.4,	462.6,	 -5.3,	 9721200,},
	{0x230118,	461.8,	467.9,	460.0,	467.9,	 +8.6,	16992900,},
	{0x230117,	457.9,	461.4,	457.9,	459.3,	  0.0,	 9489600,},
	{0x230116,	457.1,	459.6,	454.4,	459.3,	 +1.9,	 9733500,},
	{0x230113,	456.7,	462.5,	456.3,	457.4,	 +1.9,	15712800,},
	{0x230112,	453.6,	456.9,	453.0,	455.5,	 +2.1,	11732500,},
	{0x230111,	447.0,	453.8,	446.7,	453.4,	 +8.1,	12730300,},
	{0x230110,	447.0,	448.7,	444.4,	445.3,	 +0.6,	11303900,},
	{0x230106,	444.2,	446.6,	440.5,	444.7,	 +4.8,	12248100,},
	{0x230105,	440.0,	441.9,	436.4,	439.9,	 -0.1,	14217800,},
	{0x230104,	445.9,	448.9,	440.0,	440.0,	 -8.0,	21053800,},
	{0x221230,	449.8,	451.9,	448.0,	448.0,	 -3.0,	 8818700,},
	{0x221229,	447.0,	451.0,	446.1,	451.0,	 -0.7,	 8866100,},
	{0x221228,	451.6,	452.9,	449.5,	451.7,	 +1.3,	 9225300,},
	{0x221227,	450.0,	451.5,	448.2,	450.4,	 +3.9,	 8786100,},
	{0x221226,	446.0,	449.8,	445.9,	446.5,	 +2.9,	10010900,},
	{0x221223,	443.0,	444.3,	440.8,	443.6,	 +1.1,	13575400,},
	{0x221222,	444.7,	445.0,	442.1,	442.5,	 +1.2,	15013800,},
	{0x221221,	447.3,	450.5,	441.1,	441.3,	 -3.5,	19586400,},
	{0x221220,	451.7,	454.3,	442.1,	444.8,	 -4.2,	19539000,},
	{0x221219,	452.1,	453.8,	449.0,	449.0,	 -6.2,	13884100,},
	{0x221216,	457.4,	458.1,	453.7,	455.2,	 -3.7,	21303900,},
	{0x221215,	453.5,	458.9,	453.4,	458.9,	 +3.7,	12101100,},
	{0x221214,	455.0,	455.6,	452.6,	455.2,	 +4.2,	16664400,},
	{0x221213,	451.5,	455.9,	451.0,	451.0,	 +4.9,	18372200,},
	{0x221212,	443.0,	447.7,	442.5,	446.1,	 +0.9,	13810300,},
	{0x221209,	440.0,	449.0,	440.0,	445.2,	 -1.7,	23942300,},
	{0x221208,	445.0,	449.4,	440.3,	446.9,	 -3.7,	25856300,},
	{0x221207,	450.7,	453.5,	447.7,	450.6,	 -3.9,	19440500,},
	{0x221206,	453.6,	456.9,	452.7,	454.5,	 -1.2,	13029800,},
	{0x221205,	455.7,	459.6,	454.3,	455.7,	 -1.6,	13690500,},
	{0x221202,	460.0,	461.1,	454.8,	457.3,	 -7.7,	23068600,},
	{0x221201,	466.3,	468.1,	464.7,	465.0,	 -1.0,	15518300,},
	{0x221130,	469.8,	470.8,	465.9,	466.0,	 -2.7,	28064300,},
	{0x221129,	467.1,	468.8,	463.7,	468.7,	 +1.1,	15169500,},
	{0x221128,	473.5,	474.6,	465.7,	467.6,	 -2.6,	19455200,},
	{0x221125,	471.3,	472.5,	468.6,	470.2,	 +0.5,	14756700,},
	{0x221124,	471.9,	473.1,	469.2,	469.7,	 -3.5,	22228900,},
	{0x221122,	467.9,	474.8,	466.5,	473.2,	 +9.7,	18750600,},
	{0x221121,	467.4,	467.8,	463.2,	463.5,	 -2.4,	16439000,},
	{0x221118,	466.8,	470.8,	465.1,	465.9,	 -3.1,	17800400,},
	{0x221117,	470.7,	471.7,	468.9,	469.0,	 -3.9,	15502000,},
	{0x221116,	482.0,	483.6,	472.9,	472.9,	 -7.7,	28020400,},
	{0x221115,	478.3,	483.0,	477.1,	480.6,	 -0.6,	12492500,},
	{0x221114,	488.3,	489.9,	480.4,	481.2,	 -9.4,	21263500,},
	{0x221111,	488.8,	494.8,	488.8,	490.6,	 +2.3,	21659700,},
	{0x221110,	490.4,	506.1,	482.2,	488.3,	 -9.0,	39125100,},
	{0x221109,	502.4,	508.9,	496.7,	497.3,	-11.2,	19501600,},
	{0x221108,	507.9,	509.3,	504.4,	508.5,	 +4.3,	12502800,},
	{0x221107,	504.0,	508.6,	501.3,	504.2,	 +6.1,	14564000,},
	{0x221104,	502.0,	502.1,	496.9,	498.1,	 -4.6,	12383100,},
	{0x221102,	495.5,	506.5,	494.8,	502.7,	 +7.2,	17850600,},
	{0x221101,	493.1,	496.5,	491.1,	495.5,	 +5.7,	11225700,},
	{0x221031,	488.6,	491.7,	487.6,	489.8,	 +0.1,	10499200,},
	{0x221028,	492.0,	492.7,	488.6,	489.7,	 -1.8,	35226900,},
	{0x221027,	492.0,	493.5,	489.5,	491.5,	 +1.2,	11207200,},
	{0x221026,	491.2,	493.2,	488.4,	490.3,	 -2.4,	13210400,},
	{0x221025,	486.5,	495.7,	485.0,	492.7,	+10.6,	13881600,},
	{0x221024,	489.2,	489.3,	481.7,	482.1,	 -2.1,	10850200,},
	{0x221021,	481.0,	486.4,	480.6,	484.2,	 +2.7,	12480500,},
	{0x221020,	484.7,	486.5,	480.6,	481.5,	 -0.9,	10076500,},
	{0x221019,	480.4,	483.7,	478.7,	482.4,	 +0.4,	12472800,},
	{0x221018,	482.3,	484.3,	480.3,	482.0,	 -1.1,	14359400,},
	{0x221017,	483.0,	484.7,	481.4,	483.1,	 -5.7,	14226200,},
	{0x221014,	491.3,	492.9,	486.7,	488.8,	 +5.5,	14684300,},
	{0x221013,	485.8,	486.0,	482.3,	483.3,	 -1.2,	10062500,},
	{0x221012,	486.9,	487.5,	480.4,	484.5,	 -6.3,	15189000,},
	{0x221011,	491.9,	498.8,	490.2,	490.8,	 +0.7,	24375700,},
	{0x221007,	492.5,	494.0,	490.1,	490.1,	 -5.0,	16572300,},
	{0x221006,	493.6,	500.6,	493.4,	495.1,	 +2.1,	17687800,},
	{0x221005,	492.0,	495.8,	489.3,	493.0,	 -1.8,	16360500,},
	{0x221004,	482.7,	496.8,	481.6,	494.8,	+19.0,	24622100,},
	{0x221003,	469.7,	476.0,	467.1,	475.8,	+10.7,	16165200,},
	{0x220930,	470.0,	473.7,	461.1,	465.1,	 -8.7,	18249800,},
	{0x220929,	471.8,	477.9,	469.4,	473.8,	 +1.7,	16871000,},
	{0x220928,	479.5,	482.3,	468.1,	472.1,	 -4.4,	17712000,},
	{0x220927,	477.6,	485.8,	475.2,	476.5,	 -1.4,	15978500,},
	{0x220926,	493.1,	494.1,	476.4,	477.9,	-28.5,	33732400,},
	{0x220922,	500.1,	506.5,	498.1,	506.4,	 +1.8,	12890600,},
	{0x220921,	504.3,	507.3,	502.9,	504.6,	 -0.8,	14110400,},
	{0x220920,	505.0,	509.8,	503.3,	505.4,	 +0.1,	11021900,},
	{0x220916,	507.5,	509.5,	502.4,	505.3,	 -4.8,	29037100,},
	{0x220915,	514.9,	514.9,	509.5,	510.1,	 +1.2,	 7946600,},
	{0x220914,	509.5,	511.8,	507.5,	508.9,	 -4.0,	11372600,},
	{0x220913,	512.2,	515.4,	511.4,	512.9,	 +1.2,	 8910600,},
	{0x220912,	519.3,	520.9,	510.8,	511.7,	 -2.8,	12718400,},
	{0x220909,	510.6,	514.7,	510.5,	514.5,	 +3.8,	14545500,},
	{0x220908,	501.0,	512.3,	500.5,	510.7,	 +1.3,	16723100,},
	{0x220907,	509.4,	512.7,	507.3,	509.4,	 -8.6,	18733400,},
	{0x220906,	517.0,	519.2,	516.2,	518.0,	 +2.9,	 8277800,},
	{0x220905,	517.2,	518.9,	514.3,	515.1,	 +3.6,	10003600,},
	{0x220902,	510.3,	512.6,	506.7,	511.5,	 -2.7,	18157000,},
	{0x220901,	521.6,	523.7,	514.0,	514.2,	 -9.4,	15340800,},
	{0x220831,	526.0,	527.1,	522.0,	523.6,	-16.7,	23463900,},
	{0x220830,	535.2,	542.9,	535.0,	540.3,	+14.4,	19228700,},
	{0x220829,	518.5,	526.8,	516.4,	525.9,	 +2.3,	11371100,},
	{0x220826,	525.3,	526.9,	523.5,	523.6,	 -2.5,	 7969700,},
	{0x220825,	529.7,	530.7,	525.4,	526.1,	 -1.0,	 8554000,},
	{0x220824,	529.1,	531.7,	525.7,	527.1,	 +3.9,	13149700,},
	{0x220823,	527.1,	527.3,	521.6,	523.2,	 -1.7,	11426000,},
	{0x220822,	514.1,	527.0,	512.1,	524.9,	+13.1,	19970700,},
	{0x220819,	511.2,	513.3,	509.4,	511.8,	 +7.3,	12038900,},
	{0x220818,	508.5,	508.5,	503.9,	504.5,	 +0.2,	14007200,},
	{0x220817,	501.6,	506.1,	499.7,	504.3,	 +3.7,	13673300,},
	{0x220816,	500.2,	502.4,	497.5,	500.6,	 -6.3,	17581800,},
	{0x220815,	499.9,	507.9,	499.8,	506.9,	 -0.1,	16067400,},
	{0x220812,	503.3,	516.9,	496.0,	507.0,	 +9.2,	47290500,},
	{0x220810,	499.1,	501.7,	494.7,	497.8,	 +2.3,	17865700,},
	{0x220809,	495.7,	497.8,	493.6,	495.5,	 +0.5,	13700600,},
	{0x220808,	490.0,	497.4,	489.7,	495.0,	 +6.9,	14235700,},
	{0x220805,	490.0,	491.9,	482.5,	488.1,	 -6.0,	24769100,},
	{0x220804,	495.5,	497.2,	492.0,	494.1,	-10.3,	18183800,},
	{0x220803,	503.5,	506.5,	503.2,	504.4,	 +0.9,	10532200,},
	{0x220802,	499.0,	505.3,	498.9,	503.5,	-11.1,	13864200,},
	{0x220801,	513.0,	514.6,	511.2,	514.6,	 +2.9,	 9032800,},
	{0x220729,	512.0,	514.4,	510.8,	511.7,	 -1.2,	 9945600,},
	{0x220728,	511.9,	514.3,	509.9,	512.9,	 +3.8,	12643700,},
	{0x220727,	507.0,	510.1,	506.1,	509.1,	 -0.1,	 8182800,},
	{0x220726,	507.6,	513.1,	504.5,	509.2,	 +7.9,	15459300,},
	{0x220725,	496.8,	501.3,	495.2,	501.3,	 +1.9,	 8906900,},
	{0x220722,	497.4,	501.3,	496.9,	499.4,	 -6.6,	18234100,},
	{0x220721,	503.0,	507.2,	502.3,	506.0,	 -2.0,	 9198700,},
	{0x220720,	508.3,	508.5,	504.7,	508.0,	 +6.6,	11065800,},
	{0x220719,	508.3,	508.3,	500.9,	501.4,	 +8.3,	16232700,},
	{0x220715,	495.5,	496.3,	491.6,	493.1,	 -3.9,	12508700,},
	{0x220714,	499.0,	499.0,	495.4,	497.0,	 -2.1,	10028800,},
	{0x220713,	493.5,	499.8,	491.2,	499.1,	 -0.5,	10607700,},
	{0x220712,	502.1,	503.8,	498.3,	499.6,	 -6.4,	13904800,},
	{0x220711,	506.2,	511.6,	505.0,	506.0,	 +6.6,	13102100,},
	{0x220708,	500.6,	503.8,	498.5,	499.4,	 +5.6,	19270100,},
	{0x220707,	493.8,	494.5,	487.3,	493.8,	 -2.9,	18535400,},
	{0x220706,	500.0,	505.0,	490.6,	496.7,	-24.8,	31811300,},
	{0x220705,	518.2,	523.8,	515.5,	521.5,	 +9.1,	13607600,},
	{0x220704,	514.7,	515.8,	509.0,	512.4,	 -0.5,	11728400,},
	{0x220701,	511.3,	517.1,	510.4,	512.9,	 -0.8,	13490900,},
	{0x220630,	515.4,	516.9,	507.5,	513.7,	 -6.8,	14530700,},
	{0x220629,	525.3,	530.4,	518.9,	520.5,	 +2.1,	23184800,},
	{0x220628,	520.6,	522.5,	513.5,	518.4,	+10.2,	11991100,},
	{0x220627,	505.6,	512.4,	503.2,	508.2,	 +9.7,	14596000,},
	{0x220624,	502.0,	502.1,	490.2,	498.5,	-12.3,	18056400,},
	{0x220623,	510.0,	517.8,	508.6,	510.8,	 -7.3,	17348200,},
	{0x220622,	530.3,	531.8,	515.6,	518.1,	 -7.7,	19040000,},
	{0x220621,	520.0,	530.7,	515.7,	525.8,	+14.7,	17250000,},
	{0x220620,	525.0,	527.7,	507.1,	511.1,	-27.2,	28390000,},
	{0x220617,	530.0,	540.8,	525.8,	538.3,	 -6.1,	27674800,},
	{0x220616,	536.2,	549.9,	535.2,	544.4,	 +5.7,	16594900,},
	{0x220615,	554.0,	557.5,	538.4,	538.7,	-20.6,	23394600,},
	{0x220614,	558.3,	561.6,	553.5,	559.3,	 -7.9,	19040700,},
	{0x220613,	563.0,	570.6,	562.4,	567.2,	 -2.1,	16727600,},
	{0x220610,	574.9,	574.9,	567.1,	569.3,	 -9.3,	19712100,},
	{0x220609,	573.0,	580.8,	571.6,	578.6,	 +7.7,	24147200,},
	{0x220608,	568.9,	576.7,	565.2,	570.9,	 +1.9,	25374700,},
	{0x220607,	560.5,	573.9,	557.5,	569.0,	 +7.5,	23761400,},
	{0x220606,	543.3,	563.0,	542.7,	561.5,	+25.5,	32063300,},
	{0x220603,	531.6,	536.0,	530.2,	536.0,	 +5.3,	19117800,},
	{0x220602,	524.7,	531.5,	517.9,	530.7,	 +5.7,	23024700,},
	{0x220601,	519.0,	525.0,	515.8,	525.0,	 +3.8,	20041400,},
	{0x220531,	517.2,	522.2,	514.1,	521.2,	 +3.8,	63507100,},
	{0x220530,	520.0,	521.4,	516.2,	517.4,	 +1.4,	20216900,},
	{0x220527,	514.8,	519.5,	513.4,	516.0,	 +3.6,	20744800,},
	{0x220526,	517.3,	518.4,	511.4,	512.4,	 -4.5,	14026400,},
	{0x220525,	517.0,	520.9,	516.5,	516.9,	 +3.5,	22434000,},
	{0x220524,	520.1,	520.6,	513.3,	513.4,	 -2.6,	16115100,},
	{0x220523,	515.3,	525.4,	515.2,	516.0,	 +0.7,	25591300,},
	{0x220520,	511.1,	520.0,	509.3,	515.3,	 +4.2,	28009400,},
	{0x220519,	495.4,	512.3,	495.4,	511.1,	 +1.5,	20354000,},
	{0x220518,	510.4,	512.0,	502.1,	509.6,	 -3.4,	30092600,},
	{0x220517,	502.5,	517.2,	501.0,	513.0,	+15.7,	42875400,},
	{0x220516,	496.3,	504.3,	487.3,	497.3,	 +0.1,	38884600,},
	{0x220513,	464.6,	501.5,	461.3,	497.2,	+30.2,	68049800,},
	{0x220512,	469.1,	475.4,	464.6,	467.0,	 +2.7,	19157300,},
	{0x220511,	466.8,	467.7,	458.1,	464.3,	 -5.6,	19871900,},
	{0x220510,	470.7,	473.1,	463.2,	469.9,	 -7.5,	20174500,},
	{0x220509,	473.4,	479.4,	471.6,	477.4,	 +5.3,	20504900,},
	{0x220506,	475.0,	476.9,	467.0,	472.1,	+12.0,	30222700,},
	{0x220502,	454.8,	460.5,	452.3,	460.1,	 +3.9,	14359000,},
	{0x220428,	451.8,	456.4,	448.3,	456.2,	+10.2,	20709300,},
	{0x220427,	445.0,	448.7,	444.1,	446.0,	 +0.5,	18468600,},
	{0x220426,	447.3,	448.9,	443.7,	445.5,	 -0.5,	15642100,},
	{0x220425,	447.2,	452.4,	445.7,	446.0,	 -9.2,	19273900,},
	{0x220422,	455.0,	456.8,	451.8,	455.2,	 -2.8,	11469900,},
	{0x220421,	455.6,	458.8,	454.7,	458.0,	 -0.9,	11922000,},
	{0x220420,	458.8,	459.1,	455.3,	458.9,	 -1.1,	13470200,},
	{0x220419,	453.3,	462.8,	450.2,	460.0,	+10.1,	24045400,},
	{0x220418,	450.0,	451.3,	444.4,	449.9,	 -4.8,	18411200,},
	{0x220415,	454.2,	456.9,	453.0,	454.7,	 +0.1,	 7906100,},
	{0x220414,	451.8,	456.6,	450.7,	454.6,	 +7.0,	16387700,},
	{0x220413,	448.1,	449.9,	445.4,	447.6,	 +2.6,	13575700,},
	{0x220412,	447.0,	450.9,	443.5,	445.0,	 -4.0,	13674400,},
	{0x220411,	453.2,	454.9,	448.3,	449.0,	 +0.4,	11791300,},
	{0x220408,	445.0,	449.6,	444.8,	448.6,	 +2.2,	15241000,},
	{0x220407,	449.0,	450.7,	442.5,	446.4,	 -9.1,	21709400,},
	{0x220406,	456.0,	463.5,	455.1,	455.5,	 -0.9,	18542900,},
	{0x220405,	461.0,	463.3,	456.3,	456.4,	 -1.0,	12598000,},
	{0x220404,	452.0,	460.4,	450.1,	457.4,	 +5.9,	13936500,},
	{0x220401,	454.0,	454.9,	449.2,	451.5,	 -6.5,	17332500,},
	{0x220331,	462.8,	463.6,	458.0,	458.0,	 -4.1,	17795500,},
	{0x220330,	462.4,	465.6,	458.6,	462.1,	-17.6,	22435600,},
	{0x220329,	482.9,	483.5,	476.3,	479.7,	-10.1,	29660600,},
	{0x220328,	483.9,	493.2,	482.8,	489.8,	+13.9,	34266000,},
	{0x220325,	474.0,	476.7,	470.0,	475.9,	 +2.5,	16166000,},
	{0x220324,	473.0,	474.0,	468.4,	473.4,	 -1.2,	14155500,},
	{0x220323,	472.2,	474.6,	468.2,	474.6,	 +5.1,	22634500,},
	{0x220322,	469.9,	472.5,	466.3,	469.5,	+11.2,	27083400,},
	{0x220318,	454.0,	459.8,	453.5,	458.3,	 +6.8,	24834400,},
	{0x220317,	445.4,	453.9,	444.3,	451.5,	 +5.1,	18022800,},
	{0x220316,	447.7,	451.0,	445.6,	446.4,	 +1.3,	18766100,},
	{0x220315,	452.5,	453.0,	445.0,	445.1,	 -9.2,	22187800,},
	{0x220314,	455.0,	460.5,	451.3,	454.3,	 +2.7,	15571600,},
	{0x220311,	443.2,	458.4,	443.2,	451.6,	 +5.7,	22024800,},
	{0x220310,	430.0,	447.4,	429.7,	445.9,	 +6.7,	24549600,},
	{0x220309,	445.0,	453.5,	439.0,	439.2,	 -9.0,	29574400,},
	{0x220308,	473.0,	473.3,	446.8,	448.2,	-25.4,	37163700,},
	{0x220307,	474.8,	475.8,	466.9,	473.6,	 +4.7,	30359900,},
	{0x220304,	468.0,	469.9,	461.6,	468.9,	 -1.5,	16663200,},
	{0x220303,	464.6,	473.8,	462.6,	470.4,	+11.0,	26613300,},
	{0x220302,	460.0,	465.7,	453.4,	459.4,	 +2.9,	22427500,},
	{0x220301,	458.5,	459.8,	455.2,	456.5,	 +2.7,	13825500,},
	{0x220228,	445.6,	456.0,	445.6,	453.8,	 +8.3,	27894300,},
	{0x220225,	0,    	0,    	0,    	445.5,	 -8.2,	16894700,},
	{0x220224,	0,    	0,    	0,    	453.7,	 +2.2,	19314000,},
	{0x220222,	0,    	0,    	0,    	451.5,	 -2.8,	15624800,},
	{0x220221,	0,    	0,    	0,    	454.3,	 +2.1,	 9825200,},
	{0x220218,	0,    	0,    	0,    	452.2,	 -8.3,	19714900,},
	{0x220217,	0,    	0,    	0,    	460.5,	 -0.6,	17295000,},
	{0x220216,	0,    	0,    	0,    	461.1,	 -3.3,	15054900,},
	{0x220215,	0,    	0,    	0,    	464.4,	 -9.1,	20095500,},
	{0x220214,	0,    	0,    	0,    	473.5,	+13.6,	31540300,},
	{0x220210,	0,    	0,    	0,    	459.9,	 +0.9,	23171800,},
	{0x220209,	0,    	0,    	0,    	459.0,	 -8.4,	23468400,},
	{0x220208,	0,    	0,    	0,    	467.4,	 -1.3,	12060800,},
	{0x220207,	0,    	0,    	0,    	468.7,	 +6.7,	17534700,},
	{0x220204,	0,    	0,    	0,    	462.0,	 -1.2,	13122000,},
	{0x220203,	0,    	0,    	0,    	463.2,	 +3.4,	12946700,},
	{0x220202,	0,    	0,    	0,    	459.8,	 +7.9,	18668500,},
	{0x220201,	0,    	0,    	0,    	451.9,	 -3.4,	16934100,},
	{0x220131,	0,    	0,    	0,    	455.3,	 +1.4,	17219300,},
	{0x220128,	0,    	0,    	0,    	453.9,	 +8.1,	16304800,},
	{0x220127,	0,    	0,    	0,    	445.8,	 -1.5,	21082200,},
	{0x220126,	0,    	0,    	0,    	447.3,	 -4.8,	16184300,},
	{0x220125,	0,    	0,    	0,    	452.1,	 -2.1,	18053500,},
	{0x220124,	0,    	0,    	0,    	454.2,	 +4.3,	14742800,},
	{0x220121,	0,    	0,    	0,    	449.9,	 -8.4,	20750900,},
	{0x220120,	0,    	0,    	0,    	458.3,	 -2.2,	17371200,},
	{0x220119,	0,    	0,    	0,    	460.5,	 -2.9,	19645300,},
	{0x220118,	0,    	0,    	0,    	463.4,	 +3.7,	15420800,},
	{0x220117,	0,    	0,    	0,    	459.7,	 +0.2,	10233300,},
	{0x220114,	0,    	0,    	0,    	459.5,	 -0.1,	16606800,},
	{0x220113,	0,    	0,    	0,    	459.6,	 +2.7,	20870300,},
	{0x220112,	0,    	0,    	0,    	456.9,	 +7.1,	23213900,},
	{0x220111,	0,    	0,    	0,    	449.8,	 +1.6,	15324300,},
	{0x220107,	0,    	0,    	0,    	448.2,	 +6.1,	16232600,},
	{0x220106,	0,    	0,    	0,    	442.1,	 +0.1,	14531500,},
	{0x220105,	0,    	0,    	0,    	442.0,	 +8.0,	14217300,},
	{0x220104,	0,    	0,    	0,    	434.0,	 +3.7,	 9774500,},
	{0x211230,	0,    	0,    	0,    	430.3,	 -0.9,	 9014800,},
	{0x211229,	0,    	0,    	0,    	431.2,	 +2.8,	 9860800,},
	{0x211228,	0,    	0,    	0,    	428.4,	 -1.0,	11772500,},
	{0x211227,	0,    	0,    	0,    	429.4,	 -1.9,	10064500,},
	{0x211224,	0,    	0,    	0,    	431.3,	 -2.7,	 7849100,},
	{0x211223,	0,    	0,    	0,    	434.0,	 +4.6,	 9706500,},
	{0x211222,	0,    	0,    	0,    	429.4,	 +0.5,	 6708400,},
	{0x211221,	0,    	0,    	0,    	428.9,	 +4.5,	13395800,},
	{0x211220,	0,    	0,    	0,    	424.4,	-12.5,	19114200,},
	{0x211217,	0,    	0,    	0,    	436.9,	 +2.3,	18183100,},
	{0x211216,	0,    	0,    	0,    	434.6,	 +3.4,	11721500,},
	{0x211215,	0,    	0,    	0,    	431.2,	 +1.9,	13722100,},
	{0x211214,	0,    	0,    	0,    	429.3,	 -0.8,	 9931100,},
	{0x211213,	0,    	0,    	0,    	430.1,	 -0.9,	10974300,},
	{0x211210,	0,    	0,    	0,    	431.0,	 -4.0,	13918200,},
	{0x211209,	0,    	0,    	0,    	435.0,	 -3.9,	10545400,},
	{0x211208,	0,    	0,    	0,    	438.9,	 -1.2,	13478600,},
	{0x211207,	0,    	0,    	0,    	440.1,	+10.1,	15126400,},
	{0x211206,	0,    	0,    	0,    	430.0,	 +2.0,	11510900,},
	{0x211203,	0,    	0,    	0,    	428.0,	 +4.7,	18584500,},
	{0x211202,	0,    	0,    	0,    	423.3,	 -2.8,	14527000,},
	{0x211201,	0,    	0,    	0,    	426.1,	 +2.7,	12849300,},
	{0x211130,	0,    	0,    	0,    	423.4,	 -1.5,	26161700,},
	{0x211129,	0,    	0,    	0,    	424.9,	-10.8,	20097500,},
	{0x211126,	0,    	0,    	0,    	435.7,	 -4.3,	12950000,},
	{0x211125,	0,    	0,    	0,    	440.0,	 +3.7,	10733700,},
	{0x211124,	0,    	0,    	0,    	436.3,	 +4.0,	19902100,},
	{0x211122,	0,    	0,    	0,    	432.3,	 -2.3,	17187400,},
	{0x211119,	0,    	0,    	0,    	434.6,	 +1.9,	16260900,},
	{0x211118,	0,    	0,    	0,    	432.7,	-15.5,	25941500,},
	{0x211117,	0,    	0,    	0,    	448.2,	 -2.1,	14720200,},
	{0x211116,	0,    	0,    	0,    	450.3,	 -3.3,	11767700,},
	{0x211115,	0,    	0,    	0,    	453.6,	 +3.5,	15394800,},
	{0x211112,	0,    	0,    	0,    	450.1,	 -2.8,	31343200,},
};
