/*------------------------------------------------------------------------------
	インクルード
------------------------------------------------------------------------------*/
#include <stdio.h>
#include <math.h>
#include <stdarg.h>

/*------------------------------------------------------------------------------
	デファイン
------------------------------------------------------------------------------*/
#define CNT     358
#define OUT     9
#define DAYS    21
#define MAX     2300
#define MIN     1800
#define RANGE   500
#define STEP1   25
#define STEP2   50
#define DIVI    74
#define TRANGE  30000000

/*------------------------------------------------------------------------------
	マクロ
------------------------------------------------------------------------------*/
#define PRINT(x, ...)  fprintf_crlf((char *)x, ##__VA_ARGS__)

/*------------------------------------------------------------------------------
	型定義
------------------------------------------------------------------------------*/
typedef char INT8;
typedef int  INT32;

/*------------------------------------------------------------------------------
	構造体
------------------------------------------------------------------------------*/
typedef struct Field {
	INT32  date;
	double sta;
	double max;
	double min;
	double end;
	double ratio;
	INT32  trade;
} Field;

/*------------------------------------------------------------------------------
	ローカル変数
------------------------------------------------------------------------------*/
FILE *fp;
double ave5 [CNT];
double ave25[CNT];
double ave75[CNT];
double ave100[CNT];
Field tmp[CNT];

/*------------------------------------------------------------------------------
	内部参照
------------------------------------------------------------------------------*/
extern Field field[CNT];

/*------------------------------------------------------------------------------
	プロトタイプ
------------------------------------------------------------------------------*/
void difinition(void);
void sort(void);
void clear(void);
void graph(void);
void header(void);
void footer(void);
void hit(void);
void scale(void);
void dividend(void);
void fprintf_crlf(char *pStr, ...);

/*------------------------------------------------------------------------------
	書式：int main(void)
	引数：-
	戻値：int  -
	機能：スタートアップ
------------------------------------------------------------------------------*/
int main(void)
{
	fp = fopen("full.txt", "wb");
	if (fp == NULL) {printf("open error\r\n");}
	
	difinition();
	sort();
	clear();
	graph();
	header();
	footer();
	hit();
	scale();
	dividend();
	
	fclose(fp);
}

/*------------------------------------------------------------------------------
	書式：void difinition(void)
	機能：定義部分を出力
------------------------------------------------------------------------------*/
void difinition(void)
{
	INT32 i;
	INT32 cnt;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  色");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("DEFINE, RGB_BLACK,  000000");
	PRINT("DEFINE, RGB_GRAY,   C0C0C0");
	PRINT("DEFINE, RGB_RED,    F00000");
	PRINT("DEFINE, RGB_GREEN,  00F000");
	PRINT("DEFINE, RGB_BLUE,   0000F0");
	PRINT("DEFINE, RGB_MAZENTA,F000F0");
	PRINT("DEFINE, RGB_YELLOW, F0F000");
	PRINT("DEFINE, RGB_CYAN,   00F0F0");
	PRINT("DEFINE, RGB_AVE100, F0F0F0");
	PRINT("DEFINE, RGB_AVE75,  A0A0F0");
	PRINT("DEFINE, RGB_AVE25,  F0A0A0");
	PRINT("DEFINE, RGB_AVE5,   A0F0A0");
	PRINT("");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  座標");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("DEFINE, DAYS,      %d", DAYS);
	PRINT("DEFINE, MAX,       %d", MAX);
	PRINT("DEFINE, MIN,       %d", MIN);
	PRINT("DEFINE, RANGE,     %d", RANGE);
	PRINT("DEFINE, X1,        77");
	PRINT("DEFINE, Y1,        255");
	PRINT("DEFINE, X2,        767");
	PRINT("DEFINE, Y2,        863");
	PRINT("DEFINE, W,         (X2-X1)");
	PRINT("DEFINE, H,         (Y2-Y1)");
	PRINT("DEFINE, X_SCALE,   25");
	PRINT("DEFINE, Y_WEEKEND, (Y2+5)");
	
	cnt = (MAX-MIN)/STEP1;
	for (i = 0; i <= cnt; i++) {
		PRINT("DEFINE, Y_%d,     (((H*%2d)/%d)+Y1)",  MAX-STEP1*i, i, cnt);
	}
	
	PRINT("DEFINE, gX,        (X1+18)");
	PRINT("DEFINE, gW,        (W-18*2)");
	PRINT("DEFINE, tX1,       X1");
	PRINT("DEFINE, tY1,       910");
	PRINT("DEFINE, tX2,       X2");
	PRINT("DEFINE, tY2,       1030");
	PRINT("DEFINE, tW,        W");
	PRINT("DEFINE, tH,        (tY2-tY1)");
	PRINT("DEFINE, tMAX,      6000");
	PRINT("DEFINE, tMIN,      0");
	PRINT("DEFINE, tRANGE,    %d",TRANGE);
	PRINT("DEFINE, tX_SCALE,  30");
	PRINT("DEFINE, tY_6,      (((tH*0)/6)+tY1)");
	PRINT("DEFINE, tY_5,      (((tH*1)/6)+tY1)");
	PRINT("DEFINE, tY_4,      (((tH*2)/6)+tY1)");
	PRINT("DEFINE, tY_3,      (((tH*3)/6)+tY1)");
	PRINT("DEFINE, tY_2,      (((tH*4)/6)+tY1)");
	PRINT("DEFINE, tY_1,      (((tH*5)/6)+tY1)");
	PRINT("DEFINE, tY_0,      (((tH*6)/6)+tY1)");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void sort(void)
	機能：並び変える
------------------------------------------------------------------------------*/
void sort(void)
{
	INT32 i, j;
	INT32 cnt;
	
	for (i = 0; i < CNT; i++) {tmp[i] = field[CNT-1-i];}
	
	for (i = 0; i < CNT; i++) {
		ave5 [i] = 0.0;
		ave25[i] = 0.0;
		ave75[i] = 0.0;
		ave100[i] = 0.0;
		
		if (4 <= i) {
			for (j = 0; j < 5; j++) {
				ave5[i] += tmp[i-j].end;
			}
			ave5[i] /= 5;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave5[i] += tmp[i-j].end;
			}
			ave5[i] /= cnt;
		}
		
		if (24 <= i) {
			for (j = 0; j < 25; j++) {
				ave25[i] += tmp[i-j].end;
			}
			ave25[i] /= 25;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave25[i] += tmp[i-j].end;
			}
			ave25[i] /= cnt;
		}
		
		if (74 <= i) {
			for (j = 0; j < 75; j++) {
				ave75[i] += tmp[i-j].end;
			}
			ave75[i] /= 75;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave75[i] += tmp[i-j].end;
			}
			ave75[i] /= cnt;
		}
		
		if (99 <= i) {
			for (j = 0; j < 100; j++) {
				ave100[i] += tmp[i-j].end;
			}
			ave100[i] /= 100;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave100[i] += tmp[i-j].end;
			}
			ave100[i] /= cnt;
		}
	}
}

/*------------------------------------------------------------------------------
	書式：void claer(void)
	機能：塗りつぶす
------------------------------------------------------------------------------*/
void clear(void)
{
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  塗りつぶし");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("RECT, 0, 0, 840, 1050, 000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void graph(void)
	機能：グラフ部分を出力
------------------------------------------------------------------------------*/
void graph(void)
{
	INT32 i;
	INT8 fmt1[150+1] = "MOVETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f-MIN))/RANGE), %s";
	INT8 fmt2[150+1] = "LINETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f-MIN))/RANGE)";
	INT8 fmt3[150+1] = "DEFINE, GY%02X_%s, (Y2-((H*(%.1f-MIN))/RANGE))";
	INT8 fmt4[150+1] = "DEFINE, GH%02X,     ((H*(%.1f-%.1f))/RANGE)";
	INT8 fmt5[150+1] = "DEFINE, GH%02X,     %d";
	INT8 fmt6[150+1] = "RECT, X1+(W*%2d)/(DAYS+1), GY%02X_%s, 7, GH%02X, 000000, %s 1, 0, FALSE, TRUE, FALSE, FALSE";
	INT8 fmt7[150+1] = "LINE, X1+(W*%2d)/(DAYS+1)+3, GY%02X_MAX, X1+(W*%2d)/(DAYS+1)+3, GY%02X_MIN, %s 1";
	INT8 fmt8[150+1] = "MOVETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f%+.1f* 1-MIN))/RANGE), %s";
	INT8 fmt9[150+1] = "LINETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f%+.1f*%2d-MIN))/RANGE)";
	INT32 dt;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  グラフ");
	PRINT(":-------------------------------------------------------------------------------");
	
	for (i = 0; (MIN+STEP2*i) <= MAX; i++) {
		PRINT("LINE, X1+1, Y_%d, X2-1, Y_%d, RGB_GRAY, 1", MIN+STEP2*i,
														   MIN+STEP2*i);
	}
	PRINT("");
	
	for (i = 0; (MIN+STEP1*i) <= MAX; i++) {
		PRINT("LINE, X1, Y_%d, X1+4, Y_%d, RGB_BLACK, 1", MIN+STEP1*i,
														  MIN+STEP1*i);
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave100[i], "RGB_AVE100, 7");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave100[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave75[i], "RGB_AVE75, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave75[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave25[i], "RGB_AVE25, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave25[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave5[i], "RGB_AVE5, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave5[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			PRINT(fmt3, dt, "STA", tmp[i].sta);
			PRINT(fmt3, dt, "MAX", tmp[i].max);
			PRINT(fmt3, dt, "MIN", tmp[i].min);
			PRINT(fmt3, dt, "END", tmp[i].end);
			
			if (tmp[i].end >= tmp[i].sta) {
				if ((INT32)((608*(tmp[i].end-tmp[i].sta))/RANGE) == 0) {
					PRINT(fmt5, dt, 1);
				}
				else {
					PRINT(fmt4, dt, tmp[i].end, tmp[i].sta);
				}
			}
			else {
				if ((INT32)((608*(tmp[i].sta-tmp[i].end))/RANGE) == 0) {
					PRINT(fmt5, dt, 1);
				}
				else {
					PRINT(fmt4, dt, tmp[i].sta, tmp[i].end);
				}
			}
			PRINT("");
		}
	}
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			if (tmp[i].end >= tmp[i].sta) {PRINT(fmt6, i-(CNT-OUT)+1, dt, "END", dt, "RGB_RED, ");}
			else                          {PRINT(fmt6, i-(CNT-OUT)+1, dt, "STA", dt, "RGB_BLUE,");}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			if (tmp[i].end >= tmp[i].sta) {PRINT(fmt7, i-(CNT-OUT)+1, dt, i-(CNT-OUT)+1, dt, "RGB_RED, ");}
			else                          {PRINT(fmt7, i-(CNT-OUT)+1, dt, i-(CNT-OUT)+1, dt, "RGB_BLUE,");}
		}
	}
	PRINT("");
	
	if ((OUT+1) < DAYS) {
		PRINT(fmt8, OUT+1, ave100[CNT-1], ave100[CNT-1]-ave100[CNT-2], "RGB_AVE100, 7");
		PRINT(fmt9, DAYS,  ave100[CNT-1], ave100[CNT-1]-ave100[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave75[CNT-1], ave75[CNT-1]-ave75[CNT-2], "RGB_AVE75, 2");
		PRINT(fmt9, DAYS,  ave75[CNT-1], ave75[CNT-1]-ave75[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave25[CNT-1], ave25[CNT-1]-ave25[CNT-2], "RGB_AVE25, 2");
		PRINT(fmt9, DAYS,  ave25[CNT-1], ave25[CNT-1]-ave25[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave5[CNT-1], ave5[CNT-1]-ave5[CNT-2], "RGB_AVE5, 2");
		PRINT(fmt9, DAYS,  ave5[CNT-1], ave5[CNT-1]-ave5[CNT-2], DAYS-OUT);
		
		PRINT("");
	}
	
	PRINT("RECT, 0,   0,   840,     Y1,       000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, 0,   Y2+1,840,     1050-Y2-1,000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, 0,   0,   X1,      1050,     000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, X2+1,0,   840-X2-1,1050,     000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("");
	PRINT("LINE, X1, Y1, X2, Y1, RGB_BLACK, 1");
	PRINT("LINE, X1, Y1, X1, Y2, RGB_BLACK, 1");
	PRINT("LINE, X2, Y1, X2, Y2, RGB_BLACK, 1");
	PRINT("LINE, X1, Y2, X2, Y2, RGB_BLACK, 1");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void header(void)
	機能：ヘッダー部分を出力
------------------------------------------------------------------------------*/
void header(void)
{
	char fmt1[100+1] = "TEXT, 319, 25 ,1605 INPEX 20%02X年%2X月, RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt2[100+1] = "TEXT, 75,  100,%.1f,                RGB_BLACK, 000000, TRUE, Arial, 70, FALSE";
	char fmt3[100+1] = "TEXT, 75,  185,20%02X/%02X/%02X 15:00 現在, RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt4[100+1] = "TEXT, 333, 130,%s,    RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt5[100+1] = "TEXT, 333, 162,%s,    RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt6[100+1] = "TEXT, 455, 193,%.2f%,                 RGB_BLACK, 000000, TRUE, Arial, 30, FALSE";
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  ヘッダー");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("RECT, 45,  70,  250, 160, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("RECT, 49,  74,  242, 152, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("RECT, 320, 120, 220, 110, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("");
	
	if (tmp[CNT-1].end == 0) {printf("0 div error\r\n");}
	
	PRINT(fmt1, (tmp[CNT-1].date & 0x00FF0000)>>16,
	            (tmp[CNT-1].date & 0x0000FF00)>> 8);
	PRINT(fmt2, tmp[CNT-1].end);
	PRINT(fmt3, (tmp[CNT-1].date & 0x00FF0000)>>16,
	            (tmp[CNT-1].date & 0x0000FF00)>> 8,
	            (tmp[CNT-1].date & 0x000000FF)>> 0);
	PRINT(fmt4, "32円　2022年12月末");
	PRINT(fmt5, "37円　2023年 6月末");
	PRINT(fmt6, (74/tmp[CNT-1].end)*100);
	
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void footer(void)
	機能：フッター部分を出力
------------------------------------------------------------------------------*/
void footer(void)
{
	INT32 i;
	INT8 fmt1[150+1] = "RECT, X1+(W*%2d)/(DAYS+1), tY2, 6, -(tH*%10d)/tRANGE, 000000, %s 1, 0, FALSE, TRUE, FALSE, FALSE";
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  フッター");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("LINE, X1,   tY_6, X2,   tY_6, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_4, X2,   tY_4, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_2, X2,   tY_2, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_0, X2,   tY_0, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_5, X1+4, tY_5, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_3, X1+4, tY_3, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_1, X1+4, tY_1, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_5, X2,   tY_5, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_3, X2,   tY_3, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_1, X2,   tY_1, RGB_GRAY, 1");
	PRINT("");
	PRINT("TEXT, tX_SCALE,    (tY_6-10),3000, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE,    (tY_4-10),2000, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE,    (tY_2-10),1000, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE+27, (tY_0-10),0,    RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (tmp[i].ratio > 0) {
				PRINT(fmt1, i-(CNT-OUT)+1, tmp[i].trade, "RGB_RED, ");
			}
			else {
				PRINT(fmt1, i-(CNT-OUT)+1, tmp[i].trade, "RGB_BLUE,");
			}
		}
	}
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void hit(void)
	機能：出現率を出力
------------------------------------------------------------------------------*/
void hit(void)
{
	INT32 i;
	INT32 rate[100] = {0};
	INT32 pos;
	INT32 max = 0;
	INT8 fmt1[200] = "RECT, 62+6-%d, (Y_%d-%d), %d*2, %d*2, 000000, RGB_BLACK, 1, 0, FALSE, TRUE, TRUE, FALSE";
	INT32 mposi;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  出現率");
	PRINT(":-------------------------------------------------------------------------------");
	
	mposi = RANGE/STEP1;
	
	for (i = 0; i < CNT; i++) {
		pos = (tmp[i].end - MIN) / STEP1;
		
		if (pos < 0)     {continue;}
		if (pos > mposi) {continue;}
		
		rate[pos]++;
	}
	
	for (i = 0; i <= mposi; i++) {
		if (rate[i] >max) {max = rate[i];}
	}
	
	for (i = 0; i <= mposi; i++) {
		pos = MIN+i*STEP1;
		
		if (rate[i] == 0) {
		}
		else if (rate[i] <= ((max*1)/5)) {
			PRINT(fmt1, 1, pos, 1, 1, 1);
		}
		else if (rate[i] <= ((max*2)/5)) {
			PRINT(fmt1, 2, pos, 2, 2, 2);
		}
		else if (rate[i] <= ((max*3)/5)) {
			PRINT(fmt1, 3, pos, 3, 3, 3);
		}
		else if (rate[i] <= ((max*4)/5)) {
			PRINT(fmt1, 4, pos, 4, 4, 4);
		}
		else if (rate[i] <= ((max*5)/5)) {
			PRINT(fmt1, 5, pos, 5, 5, 5);
		}
	}
	PRINT("");
	
	INT8 fmt2[150+1] = "TEXT, 642, 35,平均絶対値　%.1f円, RGB_BLACK, 000000, TRUE, Arial, 16, FALSE";
	double aveAbs;
	
	aveAbs = 0.0;
	for (i = 0; i < OUT; i++) {
		aveAbs+= abs(tmp[CNT-1-i].ratio);
	}
	
	if (OUT != 0) {
		aveAbs /= OUT;
		PRINT(fmt2, aveAbs);
	}
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void scale(void)
	機能：固定部分を出力
------------------------------------------------------------------------------*/
void scale(void)
{
	INT32 i;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  目盛り");
	PRINT(":-------------------------------------------------------------------------------");
	
	for (i = 0; (MIN+STEP2*i) <= MAX; i++) {
		PRINT("TEXT, X_SCALE,(Y_%d-10),%d, RGB_BLACK, 000000, TRUE, ＭＳ ゴシック, 20, FALSE", MIN+STEP2*i,
																							   MIN+STEP2*i);
	}
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void dividend(void)
	機能：配当部分を出力
------------------------------------------------------------------------------*/
void dividend(void)
{
	INT32 i;
	double per;
	double val;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  配当");
	PRINT(":-------------------------------------------------------------------------------");
	
	per = 2.00;
	while (per < 8.00) {
		val = DIVI / (per / 100);
		
		if ((MIN <= val) && (val <= MAX)) {
			PRINT("DEFINE, Y_%.2f, (Y2-((H*(%.2f-MIN))/RANGE))", per, val);
		}
		per += 0.25;
	}
	
	per = 2.00;
	while (per < 8.00) {
		val = DIVI / (per / 100);
		
		if ((MIN <= val) && (val <= MAX)) {
			PRINT("LINE, X2-4, Y_%.2f, X2, Y_%.2f, RGB_BLACK, 1", per, per);
		}
		per += 0.25;
	}
	
	per = 2.00;
	while (per < 8.00) {
		val = DIVI / (per / 100);
		
		if ((MIN <= val) && (val <= MAX)) {
			PRINT("TEXT, 775,(Y_%.2f-6),%.2f, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE", per, per);
		}
		per += 0.25;
	}
	
//	PRINT("");
//	PRINT("TEXT,10,10,-25,RGB_BLUE,000000,TRUE,Arial,30,FALSE");
}

/*------------------------------------------------------------------------------
	書式：void fprintf_crlf(char *pStr, ...)
	引数：char *  -
	      ...     -
	機能：出力
------------------------------------------------------------------------------*/
void fprintf_crlf(char *pStr, ...)
{
	va_list args;
	
	va_start(args, pStr);
	
	vfprintf(fp, pStr, args);
	fprintf(fp, "\r\n");
	
	va_end(args); 
}

/*------------------------------------------------------------------------------
	実体
------------------------------------------------------------------------------*/
Field field[CNT] = {
	{0x231114,	2066.5,	2091.5,	2065.5,	2084.0,	 +56.0,	 8765600,},
	{0x231113,	2049.0,	2053.5,	2008.5,	2028.0,	 -12.0,	 8693400,},
	{0x231110,	2020.0,	2054.5,	2019.0,	2040.0,	 -25.0,	11038100,},
	{0x231109,	2020.0,	2069.0,	2001.0,	2065.0,	 +52.0,	11697700,},
	{0x231108,	2056.0,	2074.0,	2013.0,	2013.0,	-116.5,	15469800,},
	{0x231107,	2161.5,	2195.5,	2128.0,	2129.5,	 -40.5,	 9331600,},
	{0x231106,	2192.0,	2192.5,	2156.0,	2170.0,	  -8.5,	 8994100,},
	{0x231102,	2218.5,	2244.0,	2171.0,	2178.5,	 -43.0,	 9534400,},
	{0x231101,	2191.0,	2228.0,	2190.5,	2221.5,	 +39.0,	 7083600,},
	{0x231031,	2168.0,	2198.0,	2163.0,	2182.5,	 +25.5,	 8498700,},
	{0x231030,	2162.5,	2175.0,	2148.0,	2157.0,	 -43.5,	 7275700,},
	{0x231027,	2147.5,	2206.0,	2136.5,	2200.5,	 +63.0,	 7426100,},
	{0x231026,	2171.5,	2206.0,	2133.5,	2137.5,	 -34.0,	10317400,},
	{0x231025,	2140.0,	2196.0,	2133.5,	2171.5,	  +1.5,	 9324400,},
	{0x231024,	2155.0,	2178.5,	2118.0,	2170.0,	  -5.5,	12189800,},
	{0x231023,	2208.0,	2215.5,	2172.0,	2175.5,	 -54.5,	 9302500,},
	{0x231020,	2220.0,	2249.0,	2195.0,	2230.0,	 +48.0,	14176300,},
	{0x231019,	2216.5,	2254.0,	2164.0,	2182.0,	 -37.0,	15342100,},
	{0x231018,	2140.0,	2222.5,	2139.5,	2219.0,	 +96.0,	16943600,},
	{0x231017,	2124.5,	2151.5,	2108.5,	2123.0,	  -8.5,	 9731400,},
	{0x231016,	2160.0,	2174.0,	2125.0,	2131.5,	 +56.0,	14289300,},
	{0x231013,	2070.0,	2078.5,	2048.0,	2075.5,	 +17.0,	10313000,},
	{0x231012,	2040.0,	2069.0,	2015.5,	2058.5,	 -19.5,	13710200,},
	{0x231011,	2082.0,	2091.0,	2058.0,	2078.0,	  -3.0,	 9678900,},
	{0x231010,	2086.5,	2112.0,	2066.0,	2081.0,	+164.5,	23641000,},
	{0x231006,	1942.0,	1949.5,	1907.5,	1916.5,	 -46.5,	15170700,},
	{0x231005,	1918.0,	1976.0,	1914.0,	1963.0,	 -35.0,	22429800,},
	{0x231004,	2096.5,	2099.5,	1996.0,	1998.0,	 -82.5,	15372900,},
	{0x231003,	2150.0,	2155.0,	2060.0,	2080.5,	-144.5,	18601900,},
	{0x231002,	2248.0,	2270.0,	2225.0,	2225.0,	 -31.0,	 9217200,},
	{0x230929,	2283.0,	2290.0,	2242.0,	2256.0,	 -67.0,	10408900,},
	{0x230928,	2340.0,	2368.5,	2306.0,	2323.0,	 +56.0,	13743800,},
	{0x230927,	2275.0,	2276.0,	2247.5,	2267.0,	  +3.0,	 5410400,},
	{0x230926,	2271.0,	2275.5,	2248.5,	2264.0,	  -4.0,	 4601500,},
	{0x230925,	2276.0,	2285.0,	2246.5,	2268.0,	  +4.5,	 6349700,},
	{0x230922,	2225.0,	2280.5,	2211.0,	2263.5,	 +39.0,	 9573400,},
	{0x230921,	2238.0,	2276.0,	2209.5,	2224.5,	 -42.0,	11688900,},
	{0x230920,	2359.0,	2365.5,	2254.0,	2266.5,	 -91.5,	18884900,},
	{0x230919,	2323.0,	2358.0,	2315.0,	2358.0,	 +54.0,	10943200,},
	{0x230915,	2300.0,	2352.0,	2279.0,	2304.0,	 +36.5,	20257400,},
	{0x230914,	2262.5,	2272.5,	2213.0,	2267.5,	 +26.0,	13739500,},
	{0x230913,	2270.5,	2296.0,	2235.5,	2241.5,	 +20.5,	10814800,},
	{0x230912,	2210.5,	2232.0,	2195.0,	2221.0,	 +18.5,	 7795100,},
	{0x230911,	2220.0,	2230.5,	2186.0,	2202.5,	 +28.5,	 8780400,},
	{0x230908,	2200.0,	2228.0,	2169.5,	2174.0,	 -62.0,	12667900,},
	{0x230907,	2203.0,	2258.0,	2202.0,	2236.0,	 +36.5,	11106400,},
	{0x230906,	2200.0,	2236.5,	2194.0,	2199.5,	 +38.0,	12110000,},
	{0x230905,	2153.0,	2161.5,	2134.0,	2161.5,	 +20.0,	 7918300,},
	{0x230904,	2138.0,	2149.5,	2127.0,	2141.5,	 +40.5,	 9929700,},
	{0x230901,	2050.0,	2110.0,	2047.0,	2101.0,	 +66.0,	10643200,},
	{0x230831,	2044.0,	2045.5,	2033.5,	2035.0,	  -4.5,	 5844900,},
	{0x230830,	2044.5,	2049.5,	2034.5,	2039.5,	  +8.5,	 5806200,},
	{0x230829,	2040.0,	2059.5,	2024.0,	2031.0,	  -7.5,	 6551500,},
	{0x230827,	2027.0,	2039.0,	2022.5,	2038.5,	 +31.0,	 6728600,},
	{0x230825,	2003.5,	2014.0,	1993.5,	2007.5,	  -9.5,	 5029500,},
	{0x230824,	1999.5,	2026.0,	1995.5,	2017.0,	 +27.5,	 7424200,},
	{0x230823,	1987.0,	1993.5,	1974.5,	1989.5,	  -6.0,	 4259900,},
	{0x230822,	1984.0,	1998.0,	1977.5,	1995.5,	 +16.0,	 5624600,},
	{0x230821,	1969.0,	1994.0,	1967.0,	1979.5,	 +31.0,	 6447700,},
	{0x230818,	1955.0,	1978.5,	1948.0,	1948.5,	  -7.5,	 8936100,},
	{0x230817,	1939.5,	1980.5,	1923.5,	1956.0,	 -23.5,	11252200,},
	{0x230816,	1960.0,	1997.5,	1948.0,	1979.5,	 -45.5,	 9608100,},
	{0x230815,	2027.0,	2059.5,	2021.5,	2025.0,	 +11.0,	11258700,},
	{0x230814,	2078.5,	2098.5,	2008.0,	2014.0,	-102.0,	18384400,},
	{0x230810,	2050.0,	2140.0,	2031.5,	2116.0,	+301.5,	41718300,},
	{0x230809,	1900.0,	1900.0,	1810.5,	1814.5,	 -61.5,	11930800,},
	{0x230808,	1890.0,	1907.0,	1872.0,	1876.0,	  -5.5,	 7397100,},
	{0x230807,	1849.5,	1893.5,	1847.5,	1881.5,	 +31.5,	 7041300,},
	{0x230804,	1833.5,	1864.5,	1832.0,	1850.0,	 +34.0,	 6414800,},
	{0x230803,	1840.5,	1845.5,	1813.0,	1816.0,	 -41.5,	 5709600,},
	{0x230802,	1850.0,	1874.0,	1836.0,	1857.5,	  +8.5,	 6202300,},
	{0x230801,	1857.0,	1878.0,	1838.0,	1849.0,	 +16.5,	 7893300,},
	{0x230731,	1863.0,	1866.0,	1825.5,	1832.5,	  -7.5,	 7733200,},
	{0x230728,	1813.0,	1840.0,	1798.5,	1840.0,	 +13.5,	 7933700,},
	{0x230727,	1808.0,	1829.5,	1803.0,	1826.5,	  +3.5,	 5813200,},
	{0x230726,	1840.0,	1843.0,	1798.0,	1823.0,	 -17.0,	 9694500,},
	{0x230725,	1813.0,	1863.5,	1805.5,	1840.0,	 +51.0,	14223900,},
	{0x230724,	1780.0,	1809.0,	1765.0,	1789.0,	 +22.0,	 9436600,},
	{0x230721,	1747.5,	1775.5,	1722.0,	1767.0,	 +41.0,	 9330600,},
	{0x230720,	1709.0,	1729.0,	1701.5,	1726.0,	 +22.0,	 5748300,},
	{0x230719,	1693.0,	1708.0,	1687.5,	1704.0,	 +34.5,	 6689700,},
	{0x230718,	1672.0,	1682.0,	1664.5,	1669.5,	 -11.0,	 5184400,},
	{0x230714,	1695.0,	1698.5,	1675.5,	1680.5,	  -3.5,	 7807400,},
	{0x230713,	1686.0,	1702.5,	1677.5,	1684.0,	 +16.0,	 8073100,},
	{0x230712,	1645.5,	1673.5,	1640.0,	1668.0,	 +42.0,	11228700,},
	{0x230711,	1627.5,	1631.5,	1621.0,	1626.0,	  +9.5,	 4259800,},
	{0x230710,	1620.0,	1634.0,	1616.0,	1616.5,	 +14.5,	 7192100,},
	{0x230707,	1599.5,	1608.0,	1583.5,	1602.0,	 -19.5,	 6951300,},
	{0x230706,	1624.0,	1634.0,	1611.5,	1621.5,	  +5.5,	 6176500,},
	{0x230705,	1621.5,	1622.5,	1609.0,	1616.0,	  +7.5,	 4888700,},
	{0x230704,	1611.5,	1617.0,	1604.5,	1608.5,	  -5.0,	 3812700,},
	{0x230703,	1603.5,	1613.5,	1600.0,	1613.5,	 +15.5,	 5512000,},
	{0x230630,	1604.5,	1605.0,	1589.5,	1598.0,	  -6.0,	 5526500,},
	{0x230629,	1601.5,	1609.5,	1591.5,	1604.0,	 -17.0,	 9649200,},
	{0x230628,	1599.0,	1622.5,	1598.5,	1621.0,	  +7.5,	12864200,},
	{0x230627,	1620.5,	1621.0,	1597.5,	1613.5,	  +7.5,	 6036900,},
	{0x230626,	1604.5,	1621.5,	1594.0,	1606.0,	  +9.5,	 5136000,},
	{0x230623,	1608.5,	1628.0,	1588.0,	1596.5,	 -30.5,	 9546200,},
	{0x230622,	1635.0,	1651.0,	1624.5,	1627.0,	 +23.0,	 9906700,},
	{0x230621,	1585.0,	1606.5,	1575.5,	1604.0,	  +6.0,	 5475200,},
	{0x230620,	1616.0,	1616.0,	1593.0,	1598.0,	 -13.5,	 5721300,},
	{0x230619,	1647.5,	1649.0,	1602.0,	1611.5,	 -25.5,	 7933500,},
	{0x230616,	1607.0,	1645.5,	1607.0,	1637.0,	 +40.0,	15245400,},
	{0x230615,	1591.5,	1605.0,	1584.5,	1597.0,	  -3.0,	 7249000,},
	{0x230614,	1597.5,	1609.5,	1589.0,	1600.0,	 +25.0,	 8997100,},
	{0x230613,	1570.0,	1578.0,	1559.0,	1575.0,	  -3.0,	 8652500,},
	{0x230612,	1588.0,	1601.0,	1577.5,	1578.0,	  -8.5,	 5722200,},
	{0x230609,	1589.0,	1589.5,	1580.0,	1586.5,	  -0.5,	 7315700,},
	{0x230608,	1595.5,	1612.5,	1575.5,	1587.0,	  +6.0,	 9176700,},
	{0x230607,	1598.0,	1611.0,	1572.5,	1581.0,	 -18.5,	11759200,},
	{0x230606,	1551.5,	1599.5,	1543.5,	1599.5,	 +42.0,	12496000,},
	{0x230605,	1550.5,	1562.5,	1543.5,	1557.5,	 +42.5,	11044100,},
	{0x230602,	1497.0,	1515.0,	1489.0,	1515.0,	 +29.0,	 5806500,},
	{0x230601,	1470.0,	1489.0,	1465.0,	1486.0,	  +6.0,	 5409700,},
	{0x230531,	1496.0,	1504.0,	1480.0,	1480.0,	 -47.0,	16531100,},
	{0x230530,	1536.0,	1536.0,	1514.0,	1527.0,	 -10.0,	 4520200,},
	{0x230529,	1529.0,	1544.0,	1521.0,	1537.0,	 +26.0,	 6313000,},
	{0x230526,	1543.0,	1548.0,	1511.0,	1511.0,	 -50.0,	 8775000,},
	{0x230525,	1560.0,	1575.0,	1547.0,	1561.0,	  +8.0,	 8420900,},
	{0x230524,	1520.0,	1560.0,	1518.0,	1553.0,	 +45.0,	12742800,},
	{0x230523,	1503.0,	1518.0,	1495.0,	1508.0,	  +7.0,	 7003900,},
	{0x230522,	1493.0,	1505.0,	1491.0,	1501.0,	  +1.0,	 4047000,},
	{0x230519,	1503.0,	1504.0,	1489.0,	1500.0,	  +7.0,	 7093300,},
	{0x230518,	1500.0,	1512.0,	1493.0,	1493.0,	 +18.0,	 7606500,},
	{0x230517,	1470.0,	1482.0,	1462.0,	1475.0,	  -7.0,	 5681800,},
	{0x230516,	1492.0,	1506.0,	1481.0,	1482.0,	 +18.0,	 8211100,},
	{0x230515,	1473.0,	1477.0,	1459.0,	1464.0,	  +4.0,	 4776100,},
	{0x230512,	1476.0,	1492.0,	1454.0,	1460.0,	 -16.0,	10555900,},
	{0x230511,	1482.0,	1504.0,	1461.0,	1476.0,	 +18.0,	10531200,},
	{0x230510,	1474.0,	1481.0,	1458.0,	1458.0,	 -11.0,	 7722300,},
	{0x230509,	1466.0,	1474.0,	1462.0,	1469.0,	 +15.0,	 5677500,},
	{0x230508,	1450.0,	1459.0,	1437.0,	1454.0,	 -30.0,	11372400,},
	{0x230502,	1473.0,	1484.0,	1473.0,	1484.0,	  +3.0,	 4829100,},
	{0x230501,	1493.0,	1496.0,	1481.0,	1481.0,	  +8.0,	 4988900,},
	{0x230428,	1456.0,	1473.0,	1453.0,	1473.0,	 +21.0,	 6935700,},
	{0x230427,	1420.0,	1454.0,	1418.0,	1452.0,	  +3.0,	 6514800,},
	{0x230426,	1450.0,	1453.0,	1433.0,	1449.0,	  +2.0,	 5153600,},
	{0x230425,	1459.0,	1459.0,	1446.0,	1447.0,	  +4.0,	 7227100,},
	{0x230424,	1450.0,	1453.0,	1443.0,	1443.0,	  -5.0,	 4890000,},
	{0x230421,	1455.0,	1463.0,	1446.0,	1448.0,	 -23.0,	 7221200,},
	{0x230420,	1476.0,	1478.0,	1468.0,	1471.0,	 -14.0,	 6031200,},
	{0x230419,	1479.0,	1488.0,	1472.0,	1485.0,	 +14.0,	 6443300,},
	{0x230418,	1483.0,	1484.0,	1467.0,	1471.0,	 -32.0,	 9343000,},
	{0x230417,	1515.0,	1516.0,	1497.0,	1503.0,	 -11.0,	 5826100,},
	{0x230414,	1505.0,	1520.0,	1501.0,	1514.0,	 +17.0,	 7875300,},
	{0x230413,	1508.0,	1510.0,	1493.0,	1497.0,	  +5.0,	 6513900,},
	{0x230412,	1485.0,	1505.0,	1467.0,	1492.0,	 +26.0,	10827300,},
	{0x230411,	1448.0,	1470.0,	1439.0,	1466.0,	 +21.0,	  635530,},
	{0x230410,	1436.0,	1453.0,	1436.0,	1445.0,	 +21.0,	 4149100,},
	{0x230407,	1435.0,	1445.0,	1423.0,	1424.0,	 -12.0,	 5163400,},
	{0x230406,	1460.0,	1464.0,	1432.0,	1436.0,	 -29.0,	 7077900,},
	{0x230405,	1487.0,	1487.0,	1460.0,	1465.0,	 -28.0,	 7427100,},
	{0x230404,	1496.0,	1504.0,	1472.0,	1493.0,	 +19.0,	12077100,},
	{0x230403,	1470.0,	1485.0,	1463.0,	1474.0,	 +77.0,	15717600,},
	{0x230331,	1415.0,	1420.0,	1394.0,	1397.0,	  -2.0,	 8959400,},
	{0x230330,	1405.0,	1411.0,	1392.0,	1399.0,	 -10.0,	 5260600,},
	{0x230329,	1385.0,	1411.0,	1382.0,	1409.0,	 +40.0,	 8429900,},
	{0x230328,	1380.0,	1396.0,	1367.0,	1369.0,	 +25.0,	 8733000,},
	{0x230327,	1360.0,	1362.0,	1338.0,	1344.0,	  -9.0,	 4919900,},
	{0x230324,	1347.0,	1365.0,	1344.0,	1353.0,	 -18.0,	 5017500,},
	{0x230323,	1343.0,	1376.0,	1341.0,	1371.0,	  -1.0,	 5289300,},
	{0x230322,	1363.0,	1378.0,	1357.0,	1372.0,	 +49.0,	 8457400,},
	{0x230320,	1322.0,	1345.0,	1315.0,	1323.0,	 -26.0,	 6721000,},
	{0x230317,	1341.0,	1359.0,	1337.0,	1349.0,	 +22.0,	 9255400,},
	{0x230316,	1315.0,	1348.0,	1308.0,	1327.0,	 -61.0,	10924500,},
	{0x230315,	1401.0,	1409.0,	1385.0,	1388.0,	  -7.0,	 8161400,},
	{0x230314,	1428.0,	1428.0,	1393.0,	1395.0,	 -81.0,	10190500,},
	{0x230313,	1470.0,	1479.0,	1463.0,	1476.0,	  +5.0,	 4956700,},
	{0x230310,	1479.0,	1483.0,	1467.0,	1471.0,	 -19.0,	 7033100,},
	{0x230309,	1505.0,	1507.0,	1486.0,	1490.0,	 -11.0,	 5842900,},
	{0x230308,	1524.0,	1525.0,	1501.0,	1501.0,	 -39.0,	 9186900,},
	{0x230307,	1500.0,	1540.0,	1499.0,	1540.0,	 +45.0,	 9345100,},
	{0x230306,	1524.0,	1525.0,	1493.0,	1495.0,	 -22.0,	 7226900,},
	{0x230303,	1490.0,	1517.0,	1488.0,	1517.0,	 +35.0,	10052400,},
	{0x230302,	1485.0,	1490.0,	1475.0,	1482.0,	  +7.0,	 5912200,},
	{0x230301,	1436.0,	1476.0,	1435.0,	1475.0,	 +42.0,	 9290200,},
	{0x230228,	1438.0,	1456.0,	1433.0,	1433.0,	 -12.0,	 7771700,},
	{0x230227,	1461.0,	1463.0,	1445.0,	1445.0,	  -1.0,	 5072200,},
	{0x230224,	1465.0,	1465.0,	1444.0,	1446.0,	  -8.0,	 5558400,},
	{0x230222,	1461.0,	1466.0,	1448.0,	1454.0,	 -11.0,	 5952200,},
	{0x230221,	1436.0,	1472.0,	1430.0,	1465.0,	 +39.0,	 7786700,},
	{0x230220,	1408.0,	1426.0,	1401.0,	1426.0,	 -12.0,	 6426400,},
	{0x230217,	1435.0,	1440.0,	1424.0,	1438.0,	 -23.0,	 7412100,},
	{0x230216,	1463.0,	1466.0,	1449.0,	1461.0,	  -2.0,	 5307300,},
	{0x230215,	1479.0,	1481.0,	1454.0,	1463.0,	  -8.0,	 5274900,},
	{0x230214,	1478.0,	1484.0,	1468.0,	1471.0,	  -1.0,	 5816400,},
	{0x230213,	1437.0,	1475.0,	1435.0,	1472.0,	 +78.0,	14078500,},
	{0x230210,	1400.0,	1409.0,	1383.0,	1394.0,	 -22.0,	 9766000,},
	{0x230209,	1415.0,	1424.0,	1407.0,	1416.0,	  +7.0,	 5523700,},
	{0x230208,	1422.0,	1437.0,	1409.0,	1409.0,	 +11.0,	 6556900,},
	{0x230207,	1407.0,	1417.0,	1398.0,	1398.0,	 -10.0,	 4384000,},
	{0x230206,	1385.0,	1408.0,	1379.0,	1408.0,	 +35.0,	 6476100,},
	{0x230203,	1380.0,	1385.0,	1359.0,	1373.0,	 -37.0,	 8355300,},
	{0x230202,	1414.0,	1421.0,	1400.0,	1410.0,	 -24.0,	 5352300,},
	{0x230201,	1433.0,	1443.0,	1428.0,	1434.0,	 +14.0,	 3924100,},
	{0x230131,	1440.0,	1442.0,	1417.0,	1420.0,	 -30.0,	 5550500,},
	{0x230130,	1463.0,	1469.0,	1446.0,	1450.0,	 -15.0,	 4482500,},
	{0x230127,	1483.0,	1487.0,	1456.0,	1465.0,	 -11.0,	 4495500,},
	{0x230126,	1478.0,	1481.0,	1465.0,	1476.0,	  +4.0,	 4038300,},
	{0x230125,	1465.0,	1477.0,	1462.0,	1472.0,	  +3.0,	 3472800,},
	{0x230124,	1451.0,	1474.0,	1451.0,	1469.0,	 +15.0,	 6114300,},
	{0x230123,	1449.0,	1454.0,	1440.0,	1454.0,	 +13.0,	 4389300,},
	{0x230120,	1431.0,	1442.0,	1426.0,	1441.0,	 +28.0,	 4530000,},
	{0x230119,	1412.0,	1423.0,	1400.0,	1413.0,	 -29.0,	 5728700,},
	{0x230118,	1428.0,	1452.0,	1422.0,	1442.0,	 +22.0,	 6308100,},
	{0x230117,	1413.0,	1423.0,	1410.0,	1420.0,	 +10.0,	 4782800,},
	{0x230116,	1399.0,	1412.0,	1389.0,	1410.0,	  +4.0,	 4422800,},
	{0x230113,	1420.0,	1425.0,	1402.0,	1406.0,	  +7.0,	 7275100,},
	{0x230112,	1392.0,	1403.0,	1386.0,	1399.0,	 +21.0,	 5402700,},
	{0x230111,	1370.0,	1389.0,	1370.0,	1378.0,	  +7.0,	 5352200,},
	{0x230110,	1367.0,	1378.0,	1361.0,	1371.0,	 +15.0,	 5806500,},
	{0x230106,	1328.0,	1364.0,	1327.0,	1356.0,	 +34.0,	 8512800,},
	{0x230105,	1309.0,	1340.0,	1301.0,	1322.0,	 -15.0,	 8270900,},
	{0x230104,	1340.0,	1352.0,	1333.0,	1337.0,	 -59.0,	 9761100,},
	{0x221230,	1415.0,	1425.0,	1396.0,	1396.0,	 -20.0,	 6258600,},
	{0x221229,	1411.0,	1419.0,	1406.0,	1416.0,	 -55.0,	 8552000,},
	{0x221228,	1474.0,	1480.0,	1457.0,	1471.0,	  -6.0,	 7519200,},
	{0x221227,	1469.0,	1482.0,	1461.0,	1477.0,	 +16.0,	 5135100,},
	{0x221226,	1444.0,	1470.0,	1441.0,	1461.0,	 +36.0,	 5505700,},
	{0x221223,	1426.0,	1430.0,	1413.0,	1425.0,	 -14.0,	 5839100,},
	{0x221222,	1433.0,	1441.0,	1420.0,	1439.0,	 +35.0,	 5889200,},
	{0x221221,	1419.0,	1428.0,	1404.0,	1404.0,	  -4.0,	 7720700,},
	{0x221220,	1425.0,	1450.0,	1403.0,	1408.0,	 -18.0,	10162000,},
	{0x221219,	1450.0,	1452.0,	1424.0,	1426.0,	 -42.0,	 8053800,},
	{0x221216,	1474.0,	1480.0,	1462.0,	1468.0,	 -17.0,	 8811100,},
	{0x221215,	1460.0,	1485.0,	1460.0,	1485.0,	 +26.0,	 5441100,},
	{0x221214,	1455.0,	1465.0,	1451.0,	1459.0,	 +19.0,	 6810000,},
	{0x221213,	1446.0,	1453.0,	1438.0,	1440.0,	 +11.0,	 6975300,},
	{0x221212,	1416.0,	1431.0,	1410.0,	1429.0,	  +5.0,	 9923300,},
	{0x221209,	1427.0,	1439.0,	1421.0,	1424.0,	 -21.0,	11722400,},
	{0x221208,	1445.0,	1448.0,	1434.0,	1445.0,	 -12.0,	 8689400,},
	{0x221207,	1460.0,	1472.0,	1452.0,	1457.0,	 -28.0,	10741100,},
	{0x221206,	1470.0,	1490.0,	1467.0,	1485.0,	 -20.0,	 7523300,},
	{0x221205,	1504.0,	1514.0,	1499.0,	1505.0,	  +8.0,	 5707400,},
	{0x221202,	1518.0,	1518.0,	1491.0,	1497.0,	 -36.0,	12081500,},
	{0x221201,	1537.0,	1545.0,	1531.0,	1533.0,	   0.0,	 5533300,},
	{0x221130,	1541.0,	1548.0,	1533.0,	1533.0,	 -21.0,	 9870100,},
	{0x221129,	1528.0,	1554.0,	1519.0,	1554.0,	 +26.0,	 7763600,},
	{0x221128,	1558.0,	1563.0,	1516.0,	1528.0,	 -36.0,	11443100,},
	{0x221125,	1551.0,	1564.0,	1538.0,	1564.0,	 +28.0,	 6250200,},
	{0x221124,	1508.0,	1542.0,	1506.0,	1536.0,	 +10.0,	 7466000,},
	{0x221122,	1508.0,	1533.0,	1508.0,	1526.0,	 +20.0,	 6309400,},
	{0x221121,	1522.0,	1525.0,	1496.0,	1506.0,	 -23.0,	 9428400,},
	{0x221118,	1535.0,	1545.0,	1526.0,	1529.0,	  -5.0,	 6823100,},
	{0x221117,	1547.0,	1567.0,	1534.0,	1534.0,	 -23.0,	 7790800,},
	{0x221116,	1557.0,	1571.0,	1549.0,	1557.0,	 +30.0,	 7407500,},
	{0x221115,	1529.0,	1543.0,	1524.0,	1527.0,	 -18.0,	 8328200,},
	{0x221114,	1581.0,	1582.0,	1545.0,	1545.0,	 -24.0,	 8157300,},
	{0x221111,	1576.0,	1584.0,	1547.0,	1569.0,	  +8.0,	 9854100,},
	{0x221110,	1556.0,	1568.0,	1542.0,	1561.0,	 -35.0,	10985600,},
	{0x221109,	1598.0,	1615.0,	1570.0,	1596.0,	 -49.0,	13338500,},
	{0x221108,	1623.0,	1647.0,	1612.0,	1645.0,	 +34.0,	11464700,},
	{0x221107,	1616.0,	1621.0,	1598.0,	1611.0,	 +22.0,	11138600,},
	{0x221104,	1600.0,	1604.0,	1568.0,	1589.0,	  -1.0,	 8912600,},
	{0x221102,	1556.0,	1600.0,	1555.0,	1590.0,	 +45.0,	10395300,},
	{0x221101,	1526.0,	1545.0,	1523.0,	1545.0,	 +27.0,	 6923100,},
	{0x221031,	1497.0,	1523.0,	1492.0,	1518.0,	 +22.0,	 6101100,},
	{0x221028,	1508.0,	1512.0,	1495.0,	1496.0,	 -17.0,	12826200,},
	{0x221027,	1507.0,	1524.0,	1503.0,	1513.0,	 +23.0,	 8142800,},
	{0x221026,	1499.0,	1501.0,	1486.0,	1490.0,	 -14.0,	 7557600,},
	{0x221025,	1483.0,	1513.0,	1475.0,	1504.0,	 +20.0,	 6348000,},
	{0x221024,	1493.0,	1496.0,	1483.0,	1484.0,	  +1.0,	 5691700,},
	{0x221021,	1474.0,	1489.0,	1474.0,	1483.0,	   0.0,	 5200000,},
	{0x221020,	1471.0,	1492.0,	1464.0,	1483.0,	 +26.0,	 9483200,},
	{0x221019,	1466.0,	1467.0,	1447.0,	1457.0,	 -13.0,	 8132200,},
	{0x221018,	1466.0,	1474.0,	1452.0,	1470.0,	  -2.0,	 9515000,},
	{0x221017,	1471.0,	1476.0,	1455.0,	1472.0,	 -34.0,	 9311700,},
	{0x221014,	1516.0,	1519.0,	1499.0,	1506.0,	 +20.0,	 8438600,},
	{0x221013,	1486.0,	1492.0,	1475.0,	1486.0,	 +16.0,	 8527500,},
	{0x221012,	1475.0,	1480.0,	1457.0,	1470.0,	 -24.0,	 9099500,},
	{0x221011,	1503.0,	1523.0,	1492.0,	1494.0,	  -6.0,	 9135200,},
	{0x221007,	1527.0,	1532.0,	1500.0,	1500.0,	 -17.0,	10354200,},
	{0x221006,	1517.0,	1547.0,	1507.0,	1517.0,	 +30.0,	12770700,},
	{0x221005,	1497.0,	1502.0,	1479.0,	1487.0,	 +12.0,	11614700,},
	{0x221004,	1439.0,	1477.0,	1437.0,	1475.0,	 +75.0,	13203800,},
	{0x221003,	1362.0,	1402.0,	1358.0,	1400.0,	 +41.0,	11238400,},
	{0x220930,	1366.0,	1370.0,	1348.0,	1359.0,	  -7.0,	 9871300,},
	{0x220929,	1363.0,	1376.0,	1346.0,	1366.0,	 +33.0,	12078000,},
	{0x220928,	1360.0,	1383.0,	1324.0,	1333.0,	 -15.0,	14780600,},
	{0x220927,	1332.0,	1381.0,	1318.0,	1348.0,	 -12.0,	12644800,},
	{0x220926,	1451.0,	1459.0,	1359.0,	1360.0,	-149.0,	19341500,},
	{0x220922,	1485.0,	1510.0,	1476.0,	1509.0,	  +2.0,	 8250300,},
	{0x220921,	1507.0,	1527.0,	1504.0,	1507.0,	   0.0,	 7631800,},
	{0x220920,	1511.0,	1534.0,	1506.0,	1507.0,	  -1.0,	 6961900,},
	{0x220916,	1504.0,	1511.0,	1496.0,	1508.0,	 -28.0,	10340300,},
	{0x220915,	1545.0,	1549.0,	1526.0,	1536.0,	 +16.0,	 8472200,},
	{0x220914,	1506.0,	1534.0,	1499.0,	1520.0,	  +5.0,	10924800,},
	{0x220913,	1520.0,	1526.0,	1505.0,	1515.0,	 +22.0,	 7293000,},
	{0x220912,	1518.0,	1525.0,	1486.0,	1493.0,	 -15.0,	10010200,},
	{0x220909,	1491.0,	1509.0,	1486.0,	1508.0,	 +17.0,	11724300,},
	{0x220908,	1451.0,	1501.0,	1449.0,	1491.0,	  -9.0,	14326800,},
	{0x220907,	1497.0,	1510.0,	1484.0,	1500.0,	 -44.0,	12838000,},
	{0x220906,	1569.0,	1573.0,	1543.0,	1544.0,	 -12.0,	 9773400,},
	{0x220905,	1553.0,	1561.0,	1538.0,	1556.0,	 +12.0,	 8463500,},
	{0x220902,	1544.0,	1560.0,	1511.0,	1544.0,	 -13.0,	13329500,},
	{0x220901,	1588.0,	1597.0,	1557.0,	1557.0,	 -47.0,	13334800,},
	{0x220831,	1612.0,	1617.0,	1581.0,	1604.0,	 -59.0,	17590800,},
	{0x220830,	1630.0,	1675.0,	1627.0,	1663.0,	 +69.0,	16974300,},
	{0x220829,	1570.0,	1598.0,	1570.0,	1594.0,	 +11.0,	11192400,},
	{0x220826,	1580.0,	1609.0,	1577.0,	1583.0,	 -13.0,	 9212000,},
	{0x220825,	1602.0,	1611.0,	1579.0,	1596.0,	  +1.0,	 9632200,},
	{0x220824,	1627.0,	1649.0,	1591.0,	1595.0,	 +27.0,	17641600,},
	{0x220823,	1573.0,	1608.0,	1564.0,	1568.0,	 +30.0,	22090600,},
	{0x220822,	1500.0,	1552.0,	1498.0,	1538.0,	 +45.0,	14723700,},
	{0x220819,	1490.0,	1500.0,	1484.0,	1493.0,	 +15.0,	10795500,},
	{0x220818,	1482.0,	1492.0,	1473.0,	1478.0,	  +9.0,	 8158200,},
	{0x220817,	1457.0,	1473.0,	1446.0,	1469.0,	  +3.0,	 9828000,},
	{0x220816,	1461.0,	1473.0,	1454.0,	1466.0,	 -25.0,	 9806800,},
	{0x220815,	1481.0,	1501.0,	1473.0,	1491.0,	 -22.0,	 8301800,},
	{0x220812,	1506.0,	1521.0,	1498.0,	1513.0,	 +29.0,	12072300,},
	{0x220810,	1500.0,	1506.0,	1469.0,	1484.0,	 -10.0,	12836000,},
	{0x220809,	1550.0,	1551.0,	1492.0,	1494.0,	 +23.0,	25922800,},
	{0x220808,	1422.0,	1481.0,	1422.0,	1471.0,	 +66.0,	12394400,},
	{0x220805,	1356.0,	1413.0,	1354.0,	1405.0,	 -10.0,	10967400,},
	{0x220804,	1440.0,	1448.0,	1415.0,	1415.0,	 -66.0,	11498100,},
	{0x220803,	1470.0,	1485.0,	1466.0,	1481.0,	 +15.0,	 6201900,},
	{0x220802,	1455.0,	1476.0,	1455.0,	1466.0,	 -40.0,	 7331600,},
	{0x220801,	1520.0,	1523.0,	1498.0,	1506.0,	  -2.0,	 7338900,},
	{0x220729,	1502.0,	1529.0,	1498.0,	1508.0,	 +10.0,	10689800,},
	{0x220728,	1471.0,	1505.0,	1458.0,	1498.0,	 +55.0,	20221000,},
	{0x220727,	1447.0,	1456.0,	1426.0,	1443.0,	  +3.0,	 5661900,},
	{0x220726,	1424.0,	1447.0,	1418.0,	1440.0,	 +46.0,	 9379700,},
	{0x220725,	1385.0,	1407.0,	1382.0,	1394.0,	  -6.0,	 5000800,},
	{0x220722,	1400.0,	1410.0,	1390.0,	1400.0,	 -16.0,	 7050800,},
	{0x220721,	1435.0,	1441.0,	1415.0,	1416.0,	  -6.0,	 6338700,},
	{0x220720,	1433.0,	1433.0,	1412.0,	1422.0,	 +13.0,	 7616100,},
	{0x220719,	1405.0,	1422.0,	1393.0,	1409.0,	 +63.0,	11126800,},
	{0x220715,	1375.0,	1375.0,	1338.0,	1346.0,	 -33.0,	 9386000,},
	{0x220714,	1354.0,	1385.0,	1347.0,	1379.0,	 +13.0,	 8977800,},
	{0x220713,	1330.0,	1374.0,	1327.0,	1366.0,	 -23.0,	11148900,},
	{0x220712,	1385.0,	1401.0,	1363.0,	1389.0,	 -15.0,	10549000,},
	{0x220711,	1415.0,	1435.0,	1401.0,	1404.0,	 +30.0,	 9373700,},
	{0x220708,	1368.0,	1403.0,	1356.0,	1374.0,	 +36.0,	17505000,},
	{0x220707,	1327.0,	1343.0,	1293.0,	1338.0,	  +5.0,	19518000,},
	{0x220706,	1377.0,	1400.0,	1327.0,	1333.0,	-149.0,	24720800,},
	{0x220705,	1474.0,	1491.0,	1456.0,	1482.0,	 +32.0,	10991900,},
	{0x220704,	1434.0,	1454.0,	1415.0,	1450.0,	 +41.0,	10309700,},
	{0x220701,	1440.0,	1442.0,	1404.0,	1409.0,	 -61.0,	15833100,},
	{0x220630,	1485.0,	1493.0,	1459.0,	1470.0,	 -55.0,	12003900,},
	{0x220629,	1578.0,	1608.0,	1520.0,	1525.0,	 -44.0,	19348400,},
	{0x220628,	1550.0,	1571.0,	1532.0,	1569.0,	 +73.0,	20126800,},
	{0x220627,	1477.0,	1500.0,	1452.0,	1496.0,	 +54.0,	11732500,},
	{0x220624,	1428.0,	1453.0,	1421.0,	1442.0,	  -5.0,	13660200,},
	{0x220623,	1435.0,	1472.0,	1423.0,	1447.0,	 -39.0,	18315500,},
	{0x220622,	1562.0,	1564.0,	1468.0,	1486.0,	 -61.0,	18835800,},
	{0x220621,	1507.0,	1561.0,	1487.0,	1547.0,	 +70.0,	15442900,},
	{0x220620,	1568.0,	1578.0,	1461.0,	1477.0,	-154.0,	26997200,},
	{0x220617,	1638.0,	1652.0,	1595.0,	1631.0,	 -42.0,	23768400,},
	{0x220616,	1642.0,	1699.0,	1637.0,	1673.0,	 +11.0,	13550500,},
	{0x220615,	1697.0,	1705.0,	1647.0,	1662.0,	 -63.0,	19190700,},
	{0x220614,	1720.0,	1732.0,	1677.0,	1725.0,	 -16.0,	18131800,},
	{0x220613,	1767.0,	1795.0,	1739.0,	1741.0,	 -43.0,	15630800,},
	{0x220610,	1791.0,	1804.0,	1770.0,	1784.0,	 -23.0,	14365000,},
	{0x220609,	1810.0,	1831.0,	1777.0,	1807.0,	 +57.0,	21529300,},
	{0x220608,	1689.0,	1754.0,	1680.0,	1750.0,	 +79.0,	19676700,},
	{0x220607,	1629.0,	1682.0,	1623.0,	1671.0,	 +50.0,	13838500,},
	{0x220606,	1635.0,	1653.0,	1616.0,	1621.0,	 +15.0,	14947600,},
	{0x220603,	1604.0,	1613.0,	1583.0,	1606.0,	   0.0,	14063900,},
};
