/*------------------------------------------------------------------------------
	インクルード
------------------------------------------------------------------------------*/
#include <stdio.h>
#include <math.h>
#include <stdarg.h>

/*------------------------------------------------------------------------------
	デファイン
------------------------------------------------------------------------------*/
#define CNT     303
#define OUT     9
#define DAYS    21
#define MAX     7500
#define MIN     5500
#define RANGE   2000
#define STEP1   100
#define STEP2   500
#define DIVI    181
#define TRANGE  15000000

/*------------------------------------------------------------------------------
	マクロ
------------------------------------------------------------------------------*/
#define PRINT(x, ...)  fprintf_crlf((char *)x, ##__VA_ARGS__)

/*------------------------------------------------------------------------------
	型定義
------------------------------------------------------------------------------*/
typedef char INT8;
typedef int  INT32;

/*------------------------------------------------------------------------------
	構造体
------------------------------------------------------------------------------*/
typedef struct Field {
	INT32  date;
	double sta;
	double max;
	double min;
	double end;
	double ratio;
	INT32  trade;
} Field;

/*------------------------------------------------------------------------------
	ローカル変数
------------------------------------------------------------------------------*/
FILE *fp;
double ave5 [CNT];
double ave25[CNT];
double ave75[CNT];
double ave100[CNT];
Field tmp[CNT];

/*------------------------------------------------------------------------------
	内部参照
------------------------------------------------------------------------------*/
extern Field field[CNT];

/*------------------------------------------------------------------------------
	プロトタイプ
------------------------------------------------------------------------------*/
void difinition(void);
void sort(void);
void clear(void);
void graph(void);
void header(void);
void footer(void);
void hit(void);
void scale(void);
void dividend(void);
void fprintf_crlf(char *pStr, ...);

/*------------------------------------------------------------------------------
	書式：int main(void)
	引数：-
	戻値：int  -
	機能：スタートアップ
------------------------------------------------------------------------------*/
int main(void)
{
	fp = fopen("full.txt", "wb");
	if (fp == NULL) {printf("open error\r\n");}
	
	difinition();
	sort();
	clear();
	graph();
	header();
	footer();
	hit();
	scale();
	dividend();
	
	fclose(fp);
}

/*------------------------------------------------------------------------------
	書式：void difinition(void)
	機能：定義部分を出力
------------------------------------------------------------------------------*/
void difinition(void)
{
	INT32 i;
	INT32 cnt;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  色");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("DEFINE, RGB_BLACK,  000000");
	PRINT("DEFINE, RGB_GRAY,   C0C0C0");
	PRINT("DEFINE, RGB_RED,    F00000");
	PRINT("DEFINE, RGB_GREEN,  00F000");
	PRINT("DEFINE, RGB_BLUE,   0000F0");
	PRINT("DEFINE, RGB_MAZENTA,F000F0");
	PRINT("DEFINE, RGB_YELLOW, F0F000");
	PRINT("DEFINE, RGB_CYAN,   00F0F0");
	PRINT("DEFINE, RGB_AVE100, F0F0F0");
	PRINT("DEFINE, RGB_AVE75,  A0A0F0");
	PRINT("DEFINE, RGB_AVE25,  F0A0A0");
	PRINT("DEFINE, RGB_AVE5,   A0F0A0");
	PRINT("");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  座標");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("DEFINE, DAYS,      %d", DAYS);
	PRINT("DEFINE, MAX,       %d", MAX);
	PRINT("DEFINE, MIN,       %d", MIN);
	PRINT("DEFINE, RANGE,     %d", RANGE);
	PRINT("DEFINE, X1,        77");
	PRINT("DEFINE, Y1,        255");
	PRINT("DEFINE, X2,        767");
	PRINT("DEFINE, Y2,        863");
	PRINT("DEFINE, W,         (X2-X1)");
	PRINT("DEFINE, H,         (Y2-Y1)");
	PRINT("DEFINE, X_SCALE,   25");
	PRINT("DEFINE, Y_WEEKEND, (Y2+5)");
	
	cnt = (MAX-MIN)/STEP1;
	for (i = 0; i <= cnt; i++) {
		PRINT("DEFINE, Y_%d,     (((H*%2d)/%d)+Y1)",  MAX-STEP1*i, i, cnt);
	}
	
	PRINT("DEFINE, gX,        (X1+18)");
	PRINT("DEFINE, gW,        (W-18*2)");
	PRINT("DEFINE, tX1,       X1");
	PRINT("DEFINE, tY1,       910");
	PRINT("DEFINE, tX2,       X2");
	PRINT("DEFINE, tY2,       1030");
	PRINT("DEFINE, tW,        W");
	PRINT("DEFINE, tH,        (tY2-tY1)");
	PRINT("DEFINE, tMAX,      6000");
	PRINT("DEFINE, tMIN,      0");
	PRINT("DEFINE, tRANGE,    %d",TRANGE);
	PRINT("DEFINE, tX_SCALE,  30");
	PRINT("DEFINE, tY_6,      (((tH*0)/6)+tY1)");
	PRINT("DEFINE, tY_5,      (((tH*1)/6)+tY1)");
	PRINT("DEFINE, tY_4,      (((tH*2)/6)+tY1)");
	PRINT("DEFINE, tY_3,      (((tH*3)/6)+tY1)");
	PRINT("DEFINE, tY_2,      (((tH*4)/6)+tY1)");
	PRINT("DEFINE, tY_1,      (((tH*5)/6)+tY1)");
	PRINT("DEFINE, tY_0,      (((tH*6)/6)+tY1)");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void sort(void)
	機能：並び変える
------------------------------------------------------------------------------*/
void sort(void)
{
	INT32 i, j;
	INT32 cnt;
	
	for (i = 0; i < CNT; i++) {tmp[i] = field[CNT-1-i];}
	
	for (i = 0; i < CNT; i++) {
		ave5 [i] = 0.0;
		ave25[i] = 0.0;
		ave75[i] = 0.0;
		ave100[i] = 0.0;
		
		if (4 <= i) {
			for (j = 0; j < 5; j++) {
				ave5[i] += tmp[i-j].end;
			}
			ave5[i] /= 5;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave5[i] += tmp[i-j].end;
			}
			ave5[i] /= cnt;
		}
		
		if (24 <= i) {
			for (j = 0; j < 25; j++) {
				ave25[i] += tmp[i-j].end;
			}
			ave25[i] /= 25;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave25[i] += tmp[i-j].end;
			}
			ave25[i] /= cnt;
		}
		
		if (74 <= i) {
			for (j = 0; j < 75; j++) {
				ave75[i] += tmp[i-j].end;
			}
			ave75[i] /= 75;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave75[i] += tmp[i-j].end;
			}
			ave75[i] /= cnt;
		}
		
		if (99 <= i) {
			for (j = 0; j < 100; j++) {
				ave100[i] += tmp[i-j].end;
			}
			ave100[i] /= 100;
		}
		else {
			cnt = i+1;
			for (j = 0; j < cnt; j++) {
				ave100[i] += tmp[i-j].end;
			}
			ave100[i] /= cnt;
		}
	}
}

/*------------------------------------------------------------------------------
	書式：void claer(void)
	機能：塗りつぶす
------------------------------------------------------------------------------*/
void clear(void)
{
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  塗りつぶし");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("RECT, 0, 0, 840, 1050, 000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void graph(void)
	機能：グラフ部分を出力
------------------------------------------------------------------------------*/
void graph(void)
{
	INT32 i;
	INT8 fmt1[150+1] = "MOVETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f-MIN))/RANGE), %s";
	INT8 fmt2[150+1] = "LINETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f-MIN))/RANGE)";
	INT8 fmt3[150+1] = "DEFINE, GY%02X_%s, (Y2-((H*(%.1f-MIN))/RANGE))";
	INT8 fmt4[150+1] = "DEFINE, GH%02X,     ((H*(%.1f-%.1f))/RANGE)";
	INT8 fmt5[150+1] = "DEFINE, GH%02X,     %d";
	INT8 fmt6[150+1] = "RECT, X1+(W*%2d)/(DAYS+1), GY%02X_%s, 7, GH%02X, 000000, %s 1, 0, FALSE, TRUE, FALSE, FALSE";
	INT8 fmt7[150+1] = "LINE, X1+(W*%2d)/(DAYS+1)+3, GY%02X_MAX, X1+(W*%2d)/(DAYS+1)+3, GY%02X_MIN, %s 1";
	INT8 fmt8[150+1] = "MOVETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f%+.1f* 1-MIN))/RANGE), %s";
	INT8 fmt9[150+1] = "LINETO, X1+(W*%2d)/(DAYS+1), Y2-((H*(%.1f%+.1f*%2d-MIN))/RANGE)";
	INT32 dt;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  グラフ");
	PRINT(":-------------------------------------------------------------------------------");
	
	for (i = 0; (MIN+STEP2*i) <= MAX; i++) {
		PRINT("LINE, X1+1, Y_%d, X2-1, Y_%d, RGB_GRAY, 1", MIN+STEP2*i,
														   MIN+STEP2*i);
	}
	PRINT("");
	
	for (i = 0; (MIN+STEP1*i) <= MAX; i++) {
		PRINT("LINE, X1, Y_%d, X1+4, Y_%d, RGB_BLACK, 1", MIN+STEP1*i,
														  MIN+STEP1*i);
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave100[i], "RGB_AVE100, 7");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave100[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave75[i], "RGB_AVE75, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave75[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave25[i], "RGB_AVE25, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave25[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (i == (CNT - OUT)) {
				PRINT(fmt1, i-(CNT-OUT)+1, ave5[i], "RGB_AVE5, 2");
			}
			else {
				PRINT(fmt2, i-(CNT-OUT)+1, ave5[i]);
			}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			PRINT(fmt3, dt, "STA", tmp[i].sta);
			PRINT(fmt3, dt, "MAX", tmp[i].max);
			PRINT(fmt3, dt, "MIN", tmp[i].min);
			PRINT(fmt3, dt, "END", tmp[i].end);
			
			if (tmp[i].end >= tmp[i].sta) {
				if ((INT32)((608*(tmp[i].end-tmp[i].sta))/RANGE) == 0) {
					PRINT(fmt5, dt, 1);
				}
				else {
					PRINT(fmt4, dt, tmp[i].end, tmp[i].sta);
				}
			}
			else {
				if ((INT32)((608*(tmp[i].sta-tmp[i].end))/RANGE) == 0) {
					PRINT(fmt5, dt, 1);
				}
				else {
					PRINT(fmt4, dt, tmp[i].sta, tmp[i].end);
				}
			}
			PRINT("");
		}
	}
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			if (tmp[i].end >= tmp[i].sta) {PRINT(fmt6, i-(CNT-OUT)+1, dt, "END", dt, "RGB_RED, ");}
			else                          {PRINT(fmt6, i-(CNT-OUT)+1, dt, "STA", dt, "RGB_BLUE,");}
		}
	}
	PRINT("");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			dt = tmp[i].date & 0x000000FF;
			
			if (tmp[i].end >= tmp[i].sta) {PRINT(fmt7, i-(CNT-OUT)+1, dt, i-(CNT-OUT)+1, dt, "RGB_RED, ");}
			else                          {PRINT(fmt7, i-(CNT-OUT)+1, dt, i-(CNT-OUT)+1, dt, "RGB_BLUE,");}
		}
	}
	PRINT("");
	
	if ((OUT+1) < DAYS) {
		PRINT(fmt8, OUT+1, ave100[CNT-1], ave100[CNT-1]-ave100[CNT-2], "RGB_AVE100, 7");
		PRINT(fmt9, DAYS,  ave100[CNT-1], ave100[CNT-1]-ave100[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave75[CNT-1], ave75[CNT-1]-ave75[CNT-2], "RGB_AVE75, 2");
		PRINT(fmt9, DAYS,  ave75[CNT-1], ave75[CNT-1]-ave75[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave25[CNT-1], ave25[CNT-1]-ave25[CNT-2], "RGB_AVE25, 2");
		PRINT(fmt9, DAYS,  ave25[CNT-1], ave25[CNT-1]-ave25[CNT-2], DAYS-OUT);
		PRINT("");
		PRINT(fmt8, OUT+1, ave5[CNT-1], ave5[CNT-1]-ave5[CNT-2], "RGB_AVE5, 2");
		PRINT(fmt9, DAYS,  ave5[CNT-1], ave5[CNT-1]-ave5[CNT-2], DAYS-OUT);
		
		PRINT("");
	}
	
	PRINT("RECT, 0,   0,   840,     Y1,       000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, 0,   Y2+1,840,     1050-Y2-1,000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, 0,   0,   X1,      1050,     000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("RECT, X2+1,0,   840-X2-1,1050,     000000, FFFFFF, 0, 0, FALSE, TRUE, FALSE, FALSE");
	PRINT("");
	PRINT("LINE, X1, Y1, X2, Y1, RGB_BLACK, 1");
	PRINT("LINE, X1, Y1, X1, Y2, RGB_BLACK, 1");
	PRINT("LINE, X2, Y1, X2, Y2, RGB_BLACK, 1");
	PRINT("LINE, X1, Y2, X2, Y2, RGB_BLACK, 1");
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void header(void)
	機能：ヘッダー部分を出力
------------------------------------------------------------------------------*/
void header(void)
{
	char fmt1[100+1] = "TEXT, 319, 25 ,7974 任天堂 20%02X年%2X月, RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt2[100+1] = "TEXT, 105, 100,%.0f,                   RGB_BLACK, 000000, TRUE, Arial, 70, FALSE";
	char fmt3[100+1] = "TEXT, 75,  185,20%02X/%02X/%02X 15:00 現在,  RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt4[100+1] = "TEXT, 333, 130,%s,    RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt5[100+1] = "TEXT, 333, 162,%s,    RGB_BLACK, 000000, TRUE, Arial, 22, FALSE";
	char fmt6[100+1] = "TEXT, 455, 193,%.2f%,                  RGB_BLACK, 000000, TRUE, Arial, 30, FALSE";
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  ヘッダー");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("RECT, 45,  70,  250, 160, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("RECT, 49,  74,  242, 152, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("RECT, 320, 120, 220, 110, RGB_BLACK, 000000, 1, 0, FALSE, FALSE, FALSE, FALSE");
	PRINT("");
	
	if (tmp[CNT-1].end == 0) {printf("0 div error\r\n");}
	
	PRINT(fmt1, (tmp[CNT-1].date & 0x00FF0000)>>16,
	            (tmp[CNT-1].date & 0x0000FF00)>> 8);
	PRINT(fmt2, tmp[CNT-1].end);
	PRINT(fmt3, (tmp[CNT-1].date & 0x00FF0000)>>16,
	            (tmp[CNT-1].date & 0x0000FF00)>> 8,
	            (tmp[CNT-1].date & 0x000000FF)>> 0);
	PRINT(fmt4, "123円　2022年 3月末");
	PRINT(fmt5, " 80円　2023年 9月末");
	PRINT(fmt6, (181/tmp[CNT-1].end)*100);
	
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void footer(void)
	機能：フッター部分を出力
------------------------------------------------------------------------------*/
void footer(void)
{
	INT32 i;
	INT8 fmt1[150+1] = "RECT, X1+(W*%2d)/(DAYS+1), tY2, 6, -(tH*%10d)/tRANGE, 000000, %s 1, 0, FALSE, TRUE, FALSE, FALSE";
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  フッター");
	PRINT(":-------------------------------------------------------------------------------");
	PRINT("LINE, X1,   tY_6, X2,   tY_6, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_4, X2,   tY_4, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_2, X2,   tY_2, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_0, X2,   tY_0, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_5, X1+4, tY_5, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_3, X1+4, tY_3, RGB_GRAY, 1");
	PRINT("LINE, X1,   tY_1, X1+4, tY_1, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_5, X2,   tY_5, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_3, X2,   tY_3, RGB_GRAY, 1");
	PRINT("LINE, X2-4, tY_1, X2,   tY_1, RGB_GRAY, 1");
	PRINT("");
	PRINT("TEXT, tX_SCALE,    (tY_6-10),1500, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE,    (tY_4-10),1000, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE,    (tY_2-10), 500, RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	PRINT("TEXT, tX_SCALE+27, (tY_0-10),0,    RGB_BLACK, 000000, TRUE, Arial, 18, FALSE");
	
	for (i = 0; i < CNT; i++) {
		if ((CNT - OUT) <= i) {
			if (tmp[i].ratio > 0) {
				PRINT(fmt1, i-(CNT-OUT)+1, tmp[i].trade, "RGB_RED, ");
			}
			else {
				PRINT(fmt1, i-(CNT-OUT)+1, tmp[i].trade, "RGB_BLUE,");
			}
		}
	}
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void hit(void)
	機能：出現率を出力
------------------------------------------------------------------------------*/
void hit(void)
{
	INT32 i;
	INT32 rate[100] = {0};
	INT32 pos;
	INT32 max = 0;
	INT8 fmt1[200] = "RECT, 62+6-%d, (Y_%d-%d), %d*2, %d*2, 000000, RGB_BLACK, 1, 0, FALSE, TRUE, TRUE, FALSE";
	INT32 mposi;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  出現率");
	PRINT(":-------------------------------------------------------------------------------");
	
	mposi = RANGE/STEP1;
	
	for (i = 0; i < CNT; i++) {
		pos = (tmp[i].end - MIN) / STEP1;
		
		if (pos < 0)     {continue;}
		if (pos > mposi) {continue;}
		
		rate[pos]++;
	}
	
	for (i = 0; i <= mposi; i++) {
		if (rate[i] >max) {max = rate[i];}
	}
	
	for (i = 0; i <= mposi; i++) {
		pos = MIN+i*STEP1;
		
		if (rate[i] == 0) {
		}
		else if (rate[i] <= ((max*1)/5)) {
			PRINT(fmt1, 1, pos, 1, 1, 1);
		}
		else if (rate[i] <= ((max*2)/5)) {
			PRINT(fmt1, 2, pos, 2, 2, 2);
		}
		else if (rate[i] <= ((max*3)/5)) {
			PRINT(fmt1, 3, pos, 3, 3, 3);
		}
		else if (rate[i] <= ((max*4)/5)) {
			PRINT(fmt1, 4, pos, 4, 4, 4);
		}
		else if (rate[i] <= ((max*5)/5)) {
			PRINT(fmt1, 5, pos, 5, 5, 5);
		}
	}
	PRINT("");
	
	INT8 fmt2[150+1] = "TEXT, 642, 35,平均絶対値　%.1f円, RGB_BLACK, 000000, TRUE, Arial, 16, FALSE";
	double aveAbs;
	
	aveAbs = 0.0;
	for (i = 0; i < OUT; i++) {
		aveAbs+= abs(tmp[CNT-1-i].ratio);
	}
	
	if (OUT != 0) {
		aveAbs /= OUT;
		PRINT(fmt2, aveAbs);
	}
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void scale(void)
	機能：固定部分を出力
------------------------------------------------------------------------------*/
void scale(void)
{
	INT32 i;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  目盛り");
	PRINT(":-------------------------------------------------------------------------------");
	
	for (i = 0; (MIN+STEP2*i) <= MAX; i++) {
		PRINT("TEXT, X_SCALE,(Y_%d-10),%d, RGB_BLACK, 000000, TRUE, ＭＳ ゴシック, 20, FALSE", MIN+STEP2*i,
																							   MIN+STEP2*i);
	}
	PRINT("");
}

/*------------------------------------------------------------------------------
	書式：void dividend(void)
	機能：配当部分を出力
------------------------------------------------------------------------------*/
void dividend(void)
{
	INT32 i;
	double per;
	double val;
	
	PRINT(":-------------------------------------------------------------------------------");
	PRINT(":  配当");
	PRINT(":-------------------------------------------------------------------------------");
	
	per = 2.00;
	while (per < 8.00) {
		val = DIVI / (per / 100);
		
		if ((MIN <= val) && (val <= MAX)) {
			PRINT("DEFINE, Y_%.2f, (Y2-((H*(%.2f-MIN))/RANGE))", per, val);
		}
		per += 0.25;
	}
	
	per = 2.00;
	while (per < 8.00) {
		val = DIVI / (per / 100);
		
		if ((MIN <= val) && (val <= MAX)) {
			PRINT("LINE, X2-4, Y_%.2f, X2, Y_%.2f, RGB_BLACK, 1", per, per);
		}
		per += 0.25;
	}
	
	per = 2.00;
	while (per < 8.00) {
		val = DIVI / (per / 100);
		
		if ((MIN <= val) && (val <= MAX)) {
			PRINT("TEXT, 775,(Y_%.2f-6),%.2f, RGB_BLACK, 000000, TRUE, Arial, 12, FALSE", per, per);
		}
		per += 0.25;
	}
	
//	PRINT("");
//	PRINT("TEXT,10,10,-25,RGB_BLUE,000000,TRUE,Arial,30,FALSE");
}

/*------------------------------------------------------------------------------
	書式：void fprintf_crlf(char *pStr, ...)
	引数：char *  -
	      ...     -
	機能：出力
------------------------------------------------------------------------------*/
void fprintf_crlf(char *pStr, ...)
{
	va_list args;
	
	va_start(args, pStr);
	
	vfprintf(fp, pStr, args);
	fprintf(fp, "\r\n");
	
	va_end(args); 
}

/*------------------------------------------------------------------------------
	実体
------------------------------------------------------------------------------*/
Field field[CNT] = {
	{0x231114,	7110,	7111,	6993,	7008,	  -6,	 3366500,},
	{0x231113,	6998,	7081,	6943,	7014,	+153,	 6177500,},
	{0x231110,	7110,	7111,	6860,	6861,	-290,	 7394600,},
	{0x231109,	6874,	7160,	6840,	7151,	+377,	12503700,},
	{0x231108,	6600,	6833,	6531,	6774,	+389,	15154600,},
	{0x231107,	6410,	6448,	6365,	6385,	 -47,	 3759300,},
	{0x231106,	6360,	6433,	6295,	6432,	 +75,	 5982900,},
	{0x231102,	6365,	6419,	6323,	6357,	 +47,	 3427400,},
	{0x231101,	6343,	6377,	6291,	6310,	 +89,	 3958700,},
	{0x231031,	6171,	6235,	6116,	6221,	+104,	 4255100,},
	{0x231030,	6190,	6191,	6101,	6117,	-104,	 2919500,},
	{0x231027,	6168,	6224,	6130,	6221,	+105,	 3476300,},
	{0x231026,	6142,	6160,	6105,	6116,	 -64,	 2716200,},
	{0x231025,	6125,	6188,	6111,	6180,	 +99,	 3262800,},
	{0x231024,	6087,	6096,	6003,	6081,	 +14,	 2823900,},
	{0x231023,	6038,	6088,	6017,	6067,	 -34,	 2755000,},
	{0x231020,	6079,	6126,	6036,	6101,	  +9,	 2441200,},
	{0x231019,	6062,	6194,	6056,	6092,	 -18,	 3067300,},
	{0x231018,	6123,	6154,	6072,	6110,	 -13,	 2810200,},
	{0x231017,	6201,	6228,	6105,	6123,	 -77,	 3758300,},
	{0x231016,	6168,	6235,	6153,	6200,	  +4,	 2729200,},
	{0x231013,	6300,	6300,	6157,	6196,	-154,	 4583000,},
	{0x231012,	6327,	6384,	6301,	6350,	 +41,	 3570900,},
	{0x231011,	6292,	6336,	6253,	6309,	  -2,	 3177000,},
	{0x231010,	6245,	6315,	6194,	6311,	 +66,	 3263300,},
	{0x231006,	6201,	6317,	6172,	6245,	 +25,	 4583100,},
	{0x231005,	6148,	6223,	6105,	6220,	+112,	 4055500,},
	{0x231004,	6070,	6124,	6053,	6108,	 -52,	 4518500,},
	{0x231003,	6118,	6208,	6098,	6160,	 +30,	 4800700,},
	{0x231002,	6277,	6285,	6095,	6130,	-100,	 5289300,},
	{0x230929,	6156,	6241,	6155,	6230,	 +78,	 5586300,},
	{0x230928,	6164,	6229,	6119,	6152,	 -73,	 4392900,},
	{0x230927,	6226,	6253,	6169,	6225,	 -35,	 4207800,},
	{0x230926,	6225,	6279,	6185,	6260,	 +36,	 3333100,},
	{0x230925,	6154,	6234,	6152,	6224,	 +73,	 2616300,},
	{0x230922,	6112,	6176,	6102,	6151,	  -2,	 3391400,},
	{0x230921,	6235,	6273,	6144,	6153,	-113,	 3690000,},
	{0x230920,	6455,	6471,	6251,	6266,	-185,	 5499000,},
	{0x230919,	6363,	6451,	6333,	6451,	+113,	 4783300,},
	{0x230915,	6342,	6369,	6313,	6338,	 -16,	 5106600,},
	{0x230914,	6364,	6407,	6307,	6354,	 +45,	 3746400,},
	{0x230913,	6369,	6394,	6296,	6309,	 -60,	 3135800,},
	{0x230912,	6395,	6413,	6316,	6369,	  -1,	 2429800,},
	{0x230911,	6410,	6451,	6336,	6370,	 +12,	 3758900,},
	{0x230908,	6368,	6419,	6314,	6358,	 -10,	 5422100,},
	{0x230907,	6331,	6368,	6309,	6368,	 +45,	 2711300,},
	{0x230906,	6300,	6362,	6295,	6323,	 +49,	 2848000,},
	{0x230905,	6296,	6318,	6240,	6274,	  +7,	 2700400,},
	{0x230904,	6292,	6302,	6246,	6267,	  -1,	 2680900,},
	{0x230901,	6260,	6303,	6235,	6268,	  +1,	 2971400,},
	{0x230831,	6219,	6289,	6213,	6267,	 +48,	 3918500,},
	{0x230830,	6195,	6265,	6185,	6219,	 +47,	 3224900,},
	{0x230829,	6194,	6239,	6166,	6172,	  -3,	 2235100,},
	{0x230828,	6150,	6181,	6138,	6175,	 +92,	 2148100,},
	{0x230825,	6091,	6126,	6073,	6083,	 -62,	 2500400,},
	{0x230824,	6227,	6227,	6142,	6145,	 -66,	 2777500,},
	{0x230823,	6139,	6211,	6128,	6211,	 +52,	 2131300,},
	{0x230822,	6186,	6188,	6128,	6159,	 +31,	 1912700,},
	{0x230821,	6110,	6169,	6091,	6128,	 +14,	 2440700,},
	{0x230818,	6130,	6173,	6084,	6114,	 -66,	 2896000,},
	{0x230817,	6276,	6289,	6152,	6180,	-112,	 3569500,},
	{0x230816,	6315,	6332,	6259,	6292,	  -2,	 2697900,},
	{0x230815,	6294,	6301,	6261,	6294,	 +46,	 2054300,},
	{0x230814,	6250,	6311,	6225,	6248,	  -3,	 2724000,},
	{0x230810,	6166,	6255,	6139,	6251,	+106,	 3577600,},
	{0x230809,	6152,	6193,	6135,	6145,	 -14,	 2857300,},
	{0x230808,	6236,	6277,	6153,	6159,	 -73,	 3817800,},
	{0x230807,	6148,	6265,	6144,	6232,	 +60,	 4554000,},
	{0x230804,	6230,	6250,	6114,	6172,	-185,	 9943800,},
	{0x230803,	6355,	6379,	6282,	6357,	  +2,	 4110800,},
	{0x230802,	6410,	6431,	6335,	6355,	-104,	 3578700,},
	{0x230801,	6451,	6468,	6365,	6459,	  +9,	 3219100,},
	{0x230731,	6425,	6471,	6393,	6450,	 +96,	 4426200,},
	{0x230728,	6295,	6380,	6247,	6354,	 -22,	 4523900,},
	{0x230727,	6306,	6393,	6292,	6376,	 +76,	 3242100,},
	{0x230726,	6385,	6394,	6300,	6300,	-143,	 4083600,},
	{0x230725,	6460,	6476,	6398,	6443,	 -68,	 3405600,},
	{0x230724,	6498,	6539,	6480,	6511,	 +93,	 3414300,},
	{0x230721,	6426,	6460,	6398,	6418,	  -8,	 2876600,},
	{0x230720,	6419,	6472,	6390,	6426,	  -7,	 2981900,},
	{0x230719,	6403,	6438,	6390,	6433,	 +73,	 2675300,},
	{0x230718,	6350,	6399,	6339,	6360,	 -29,	 2531200,},
	{0x230714,	6485,	6492,	6360,	6389,	 -35,	 3591800,},
	{0x230713,	6350,	6433,	6305,	6424,	+124,	 3366300,},
	{0x230712,	6399,	6487,	6300,	6300,	 +43,	 4659000,},
	{0x230711,	6355,	6359,	6223,	6257,	 -48,	 3540600,},
	{0x230710,	6305,	6349,	6246,	6305,	 -46,	 4094000,},
	{0x230707,	6359,	6412,	6334,	6351,	 +37,	 4955200,},
	{0x230706,	6469,	6516,	6293,	6314,	-198,	 5998800,},
	{0x230705,	6530,	6556,	6484,	6512,	  -7,	 3116800,},
	{0x230704,	6560,	6569,	6510,	6519,	 -68,	 2862800,},
	{0x230703,	6589,	6608,	6545,	6587,	 +45,	 3174900,},
	{0x230630,	6500,	6553,	6425,	6542,	 -40,	 6664300,},
	{0x230629,	6571,	6640,	6557,	6582,	 +62,	 5521700,},
	{0x230628,	6418,	6544,	6395,	6520,	+128,	 6777200,},
	{0x230627,	6300,	6396,	6232,	6392,	+103,	 5804500,},
	{0x230626,	6231,	6313,	6180,	6289,	 +59,	 3705900,},
	{0x230623,	6380,	6384,	6182,	6230,	 -88,	 4439800,},
	{0x230622,	6225,	6428,	6223,	6318,	+106,	 9574200,},
	{0x230621,	6241,	6246,	6184,	6212,	 -30,	 3028700,},
	{0x230620,	6202,	6242,	6156,	6242,	 +10,	 3106700,},
	{0x230619,	6250,	6259,	6169,	6232,	 -34,	 3490000,},
	{0x230616,	6200,	6277,	6149,	6266,	 +41,	 6516500,},
	{0x230615,	6200,	6357,	6197,	6225,	 +68,	 7487200,},
	{0x230614,	6190,	6192,	6137,	6157,	 -24,	 3752400,},
	{0x230613,	6159,	6194,	6127,	6181,	 +55,	 3726900,},
	{0x230612,	6130,	6159,	6105,	6126,	 +28,	 3741800,},
	{0x230609,	6040,	6112,	6010,	6098,	+115,	 6745800,},
	{0x230608,	6049,	6084,	5938,	5983,	 -70,	 4198200,},
	{0x230607,	6118,	6128,	6003,	6053,	 -67,	 5335600,},
	{0x230606,	6068,	6120,	6039,	6120,	 +37,	 3507900,},
	{0x230605,	6100,	6124,	6033,	6083,	 +33,	 4309800,},
	{0x230602,	5980,	6085,	5977,	6050,	 +96,	 5926600,},
	{0x230601,	5917,	5975,	5901,	5954,	 +18,	 4029800,},
	{0x230531,	6006,	6013,	5895,	5936,	 -54,	13218800,},
	{0x230530,	5892,	6015,	5890,	5990,	 +81,	 4847400,},
	{0x230529,	5967,	5976,	5882,	5909,	 -34,	 5562300,},
	{0x230526,	5920,	5977,	5910,	5943,	 +67,	 4494900,},
	{0x230525,	5891,	5917,	5854,	5876,	 -54,	 4434600,},
	{0x230524,	5950,	5972,	5881,	5930,	 -58,	 4220900,},
	{0x230523,	6060,	6107,	5934,	5988,	 -72,	 7209500,},
	{0x230522,	5999,	6060,	5989,	6060,	 +83,	 5098500,},
	{0x230519,	6074,	6082,	5968,	5977,	 -66,	 6094600,},
	{0x230518,	6048,	6063,	5998,	6043,	+118,	 8556600,},
	{0x230517,	5880,	5966,	5861,	5925,	 +78,	 7467500,},
	{0x230516,	5825,	5870,	5796,	5847,	 +47,	 6054900,},
	{0x230515,	5800,	5808,	5728,	5800,	 +42,	 5628700,},
	{0x230512,	5688,	5767,	5652,	5758,	+127,	 7818600,},
	{0x230511,	5679,	5722,	5590,	5631,	 -94,	 5811500,},
	{0x230510,	5780,	5781,	5657,	5725,	  -5,	 8949800,},
	{0x230509,	5708,	5755,	5673,	5730,	  -9,	 6965800,},
	{0x230508,	5730,	5798,	5712,	5739,	 +46,	 8361200,},
	{0x230502,	5691,	5711,	5668,	5693,	  +2,	 4023400,},
	{0x230501,	5788,	5799,	5656,	5691,	 -30,	 5363400,},
	{0x230428,	5655,	5721,	5645,	5721,	 +93,	 5439300,},
	{0x230427,	5594,	5647,	5577,	5628,	 +10,	 4188300,},
	{0x230426,	5620,	5642,	5577,	5618,	 -31,	 4642500,},
	{0x230425,	5590,	5736,	5566,	5649,	 +58,	 7607900,},
	{0x230424,	5511,	5604,	5490,	5591,	 +71,	 4516600,},
	{0x230421,	5531,	5554,	5506,	5520,	  +4,	 3606000,},
	{0x230420,	5539,	5539,	5460,	5516,	 -26,	 4160400,},
	{0x230419,	5541,	5547,	5511,	5542,	 -18,	 4440400,},
	{0x230418,	5500,	5560,	5485,	5560,	+103,	 5630300,},
	{0x230417,	5499,	5499,	5423,	5457,	 -10,	 3467500,},
	{0x230414,	5393,	5480,	5379,	5467,	 +88,	 5924400,},
	{0x230413,	5431,	5435,	5376,	5379,	 -87,	 4182700,},
	{0x230412,	5413,	5488,	5396,	5466,	 +53,	 5148200,},
	{0x230411,	5505,	5543,	5407,	5413,	  +7,	 9397600,},
	{0x230410,	5291,	5410,	5271,	5406,	+208,	 7136300,},
	{0x230407,	5325,	5326,	5187,	5198,	 -52,	 4302700,},
	{0x230406,	5235,	5297,	5230,	5250,	  +5,	 4175400,},
	{0x230405,	5363,	5367,	5241,	5245,	-167,	 6830300,},
	{0x230404,	5210,	5414,	5194,	5412,	+239,	10423400,},
	{0x230403,	5209,	5218,	5150,	5173,	 +42,	 4140400,},
	{0x230331,	5098,	5141,	5082,	5131,	 +52,	 4148100,},
	{0x230330,	5100,	5122,	5066,	5079,	-100,	 3668500,},
	{0x230329,	5087,	5181,	5051,	5179,	 +96,	 5495300,},
	{0x230328,	5115,	5136,	5074,	5083,	 -12,	 3167800,},
	{0x230327,	5099,	5131,	5087,	5095,	 +37,	 2570100,},
	{0x230324,	5079,	5079,	5031,	5058,	 -18,	 3528800,},
	{0x230323,	5080,	5088,	5037,	5076,	  -4,	 3157600,},
	{0x230322,	5041,	5091,	5011,	5080,	 +47,	 4871800,},
	{0x230320,	5143,	5146,	5030,	5033,	-111,	 4651500,},
	{0x230317,	5122,	5148,	5093,	5144,	 +69,	 4791900,},
	{0x230316,	5010,	5087,	4996,	5075,	  -7,	 4511500,},
	{0x230315,	5034,	5109,	5034,	5082,	 +17,	 4393600,},
	{0x230314,	5091,	5091,	5028,	5065,	 -64,	 4934100,},
	{0x230313,	5112,	5131,	5097,	5129,	 -19,	 3586700,},
	{0x230310,	5152,	5181,	5136,	5148,	 -79,	 5040700,},
	{0x230309,	5160,	5236,	5159,	5227,	 +69,	 4169600,},
	{0x230308,	5130,	5183,	5121,	5158,	 -19,	 3768500,},
	{0x230307,	5182,	5206,	5167,	5177,	  -1,	 3147900,},
	{0x230306,	5180,	5215,	5170,	5178,	 +20,	 3255300,},
	{0x230303,	5101,	5165,	5093,	5158,	 +22,	 4696500,},
	{0x230302,	5058,	5141,	5053,	5136,	 +14,	 4997600,},
	{0x230301,	5097,	5126,	5041,	5122,	  -2,	 6107900,},
	{0x230228,	5145,	5187,	5124,	5124,	 -74,	 6918600,},
	{0x230227,	5200,	5238,	5183,	5198,	 -99,	 4848800,},
	{0x230224,	5291,	5313,	5252,	5297,	 -15,	 4381800,},
	{0x230222,	5389,	5391,	5312,	5312,	-100,	 4503200,},
	{0x230221,	5470,	5480,	5412,	5412,	 -52,	 3638900,},
	{0x230220,	5498,	5498,	5419,	5464,	  +8,	 4224100,},
	{0x230217,	5488,	5499,	5425,	5456,	 -42,	 4440300,},
	{0x230216,	5432,	5499,	5391,	5498,	+162,	 6867300,},
	{0x230215,	5370,	5374,	5305,	5336,	  +8,	 4432200,},
	{0x230214,	5230,	5339,	5230,	5328,	+104,	 5742800,},
	{0x230213,	5246,	5257,	5212,	5224,	 -83,	 7001000,},
	{0x230210,	5290,	5379,	5281,	5307,	 +28,	10996200,},
	{0x230209,	5192,	5292,	5171,	5279,	 +78,	14233000,},
	{0x230208,	5280,	5298,	5146,	5201,	-423,	27112900,},
	{0x230207,	5590,	5644,	5567,	5624,	  +3,	 4215900,},
	{0x230206,	5630,	5647,	5616,	5621,	  -1,	 3580900,},
	{0x230203,	5608,	5627,	5573,	5622,	 +40,	 3281200,},
	{0x230202,	5596,	5616,	5571,	5582,	  +2,	 2751200,},
	{0x230201,	5590,	5623,	5580,	5580,	 -45,	 2409900,},
	{0x230131,	5680,	5689,	5615,	5625,	 +27,	 3547100,},
	{0x230130,	5595,	5622,	5567,	5598,	 -32,	 3956900,},
	{0x230127,	5660,	5669,	5617,	5630,	  -5,	 2678500,},
	{0x230126,	5602,	5660,	5602,	5635,	 +61,	 3524000,},
	{0x230125,	5567,	5591,	5545,	5574,	 +18,	 3152700,},
	{0x230124,	5578,	5613,	5555,	5556,	 +21,	 3889900,},
	{0x230123,	5551,	5573,	5512,	5535,	 +25,	 3268600,},
	{0x230120,	5522,	5582,	5495,	5510,	 -25,	 3791600,},
	{0x230119,	5550,	5556,	5498,	5535,	 -73,	 3101300,},
	{0x230118,	5520,	5627,	5493,	5608,	+118,	 5079100,},
	{0x230117,	5413,	5496,	5413,	5490,	 +77,	 4018600,},
	{0x230116,	5385,	5470,	5361,	5413,	 +16,	 4215300,},
	{0x230113,	5381,	5473,	5381,	5397,	 -50,	 5983300,},
	{0x230112,	5469,	5488,	5436,	5447,	-100,	 7380700,},
	{0x230111,	5497,	5548,	5482,	5547,	 +77,	 5320000,},
	{0x230110,	5483,	5565,	5470,	5470,	 -13,	 5620700,},
	{0x230106,	5466,	5483,	5407,	5483,	 -47,	 5181300,},
	{0x230105,	5517,	5603,	5496,	5530,	 +43,	 4229200,},
	{0x230104,	5444,	5546,	5405,	5487,	 -45,	 5632900,},
	{0x221230,	5595,	5627,	5530,	5532,	 -76,	 4709000,},
	{0x221229,	5610,	5638,	5601,	5608,	 -12,	 3244800,},
	{0x221228,	5606,	5620,	5588,	5620,	 +14,	 2827400,},
	{0x221227,	5649,	5654,	5593,	5606,	 -11,	 2227000,},
	{0x221226,	5620,	5648,	5600,	5617,	  +3,	 1601500,},
	{0x221223,	5601,	5637,	5587,	5614,	 -15,	 3057200,},
	{0x221222,	5576,	5649,	5557,	5629,	 +89,	 3868000,},
	{0x221221,	5519,	5596,	5509,	5540,	  -1,	 8805100,},
	{0x221220,	5608,	5627,	5502,	5541,	 -51,	 9024900,},
	{0x221219,	5600,	5624,	5566,	5592,	 -53,	 5775200,},
	{0x221216,	5680,	5699,	5645,	5645,	 -73,	 5534600,},
	{0x221215,	5701,	5729,	5683,	5718,	 -31,	 3459600,},
	{0x221214,	5705,	5749,	5695,	5749,	 +57,	 3091800,},
	{0x221213,	5690,	5727,	5675,	5692,	  +8,	 3191500,},
	{0x221212,	5680,	5705,	5672,	5684,	 -32,	 3059600,},
	{0x221209,	5771,	5786,	5716,	5716,	 +10,	 4525700,},
	{0x221208,	5778,	5789,	5672,	5706,	 -76,	 5081100,},
	{0x221207,	5726,	5847,	5687,	5782,	 +19,	 7701200,},
	{0x221206,	5738,	5788,	5714,	5763,	 +79,	 4892200,},
	{0x221205,	5700,	5710,	5657,	5684,	 -42,	 5004400,},
	{0x221202,	5750,	5757,	5690,	5726,	 -82,	 6360900,},
	{0x221201,	5911,	5922,	5805,	5808,	 -86,	 6006600,},
	{0x221130,	5868,	5933,	5835,	5894,	 +26,	 6667500,},
	{0x221129,	5875,	5925,	5854,	5868,	 -38,	 4146600,},
	{0x221128,	5920,	5927,	5865,	5906,	 -53,	 4301200,},
	{0x221125,	5999,	6005,	5936,	5959,	 -17,	 4488500,},
	{0x221124,	5994,	6048,	5970,	5976,	 +42,	 7901600,},
	{0x221122,	5917,	5938,	5861,	5934,	 +47,	 5003200,},
	{0x221121,	5900,	5924,	5838,	5887,	 -33,	 4830800,},
	{0x221118,	5879,	5925,	5826,	5920,	 +41,	 6211200,},
	{0x221117,	5862,	5879,	5814,	5879,	 +64,	 5730600,},
	{0x221116,	5780,	5818,	5721,	5815,	 +51,	 5458500,},
	{0x221115,	5744,	5846,	5736,	5764,	+105,	 7501400,},
	{0x221114,	5700,	5743,	5659,	5659,	-100,	 9525600,},
	{0x221111,	5856,	5882,	5716,	5759,	  +3,	11026200,},
	{0x221110,	5761,	5798,	5700,	5756,	 -27,	10928700,},
	{0x221109,	6000,	6001,	5750,	5783,	-442,	21530100,},
	{0x221108,	6200,	6283,	6193,	6225,	+104,	 7539600,},
	{0x221107,	6030,	6147,	6012,	6121,	+167,	 6345100,},
	{0x221104,	6010,	6020,	5931,	5954,	-116,	 5975900,},
	{0x221102,	6065,	6095,	6042,	6070,	  -5,	 4322000,},
	{0x221101,	6107,	6115,	6063,	6075,	  +5,	 3787100,},
	{0x221031,	5951,	6095,	5943,	6070,	+123,	 5705100,},
	{0x221028,	5977,	5998,	5918,	5947,	 -37,	 5412600,},
	{0x221027,	6072,	6082,	5978,	5984,	 -88,	 4633900,},
	{0x221026,	5997,	6090,	5993,	6072,	 +87,	 5230000,},
	{0x221025,	6033,	6033,	5961,	5985,	 -15,	 3948400,},
	{0x221024,	6086,	6094,	6000,	6000,	 -36,	 3441700,},
	{0x221021,	6029,	6082,	6016,	6036,	 -60,	 3563100,},
	{0x221020,	6000,	6099,	5990,	6096,	 +44,	 4682100,},
	{0x221019,	6131,	6159,	6045,	6052,	 -63,	 4485500,},
	{0x221018,	6140,	6188,	6074,	6115,	 +10,	 4577600,},
	{0x221017,	6100,	6120,	6031,	6105,	 -64,	 4937100,},
	{0x221014,	6108,	6213,	6068,	6169,	+139,	 7493600,},
	{0x221013,	6100,	6191,	6028,	6030,	  +5,	 5940600,},
	{0x221012,	5937,	6039,	5933,	6025,	 +24,	 4682100,},
	{0x221011,	6006,	6068,	5973,	6001,	 -55,	 5202400,},
	{0x221007,	6001,	6107,	5980,	6056,	   0,	 5123500,},
	{0x221006,	6075,	6169,	6010,	6056,	 +45,	 9120900,},
	{0x221005,	6075,	6144,	6007,	6011,	 -39,	 6492300,},
	{0x221004,	5861,	6050,	5784,	6050,	+230,	10450800,},
	{0x221003,	5718,	5839,	5610,	5820,	 -34,	 6811500,},
	{0x220930,	5950,	6008,	5737,	5854,	-189,	 8834200,},
	{0x220929,	6021,	6153,	6006,	6043,	 +73,	 7247800,},
	{0x220928,	6065,	6070,	5915,	5970,	 -98,	 7149000,},
	{0x220927,	5999,	6119,	5985,	6068,	+119,	 6632000,},
	{0x220926,	6063,	6068,	5932,	5949,	-183,	 9058000,},
	{0x220922,	6080,	6179,	6070,	6132,	 +22,	 6754000,},
	{0x220921,	6140,	6227,	6099,	6110,	 -73,	 7218000,},
	{0x220920,	6209,	6240,	6134,	6183,	 +74,	 8018000,},
	{0x220916,	6150,	6180,	6051,	6109,	-131,	11124000,},
	{0x220915,	6146,	6342,	6137,	6240,	+104,	14135000,},
	{0x220914,	6166,	6182,	6033,	6136,	 -85,	12132000,},
	{0x220913,	6050,	6249,	6050,	6221,	+325,	18652000,},
	{0x220912,	5870,	5929,	5828,	5896,	 +68,	 4672000,},
	{0x220909,	5851,	5929,	5821,	5828,	 -23,	 6847000,},
	{0x220908,	5791,	5851,	5766,	5851,	 +81,	 6479000,},
	{0x220907,	5747,	5802,	5735,	5770,	 +62,	 6303000,},
	{0x220906,	5620,	5741,	5594,	5708,	 +65,	 4920000,},
	{0x220905,	5668,	5707,	5634,	5643,	 -24,	 3991000,},
	{0x220902,	5709,	5715,	5645,	5667,	 -44,	 5305000,},
	{0x220901,	5688,	5727,	5676,	5711,	 +12,	 4384000,},
	{0x220831,	5735,	5735,	5681,	5699,	 -48,	 5049000,},
	{0x220830,	5724,	5767,	5719,	5747,	 +23,	 3352000,},
	{0x220829,	5720,	5747,	5697,	5724,	 -40,	 4308000,},
	{0x220826,	5797,	5826,	5762,	5764,	 -27,	 3680000,},
	{0x220825,	5820,	5828,	5760,	5791,	  +6,	 3536000,},
	{0x220824,	5900,	5902,	5785,	5785,	-155,	 7488000,},
	{0x220823,	6008,	6020,	5918,	5940,	   0,	 4406000,},
};
